import unittest

from PySide.QtCore import QObject
from PySide.QtScript import  QScriptEngine

class QScriptEngineTest(unittest.TestCase):

    def testQScriptEngine(self):
         engine = QScriptEngine()
         obj = engine.evaluate("({ unitName: 'Celsius', toKelvin: function(x) { return x + 273; } })")
         toKelvin = obj.property("toKelvin")
         result = toKelvin.call(obj, [100])
         self.assertEqual(result.toNumber(), 373)



#!/usr/bin/python

# This file is part of PySide: Python for Qt
#
# Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
#
# Contact: PySide team <contact@pyside.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA


# This is a small script printing out Qt binding class hierarchies
# for comparison purposes.
#
# Usage:
#
# ./list-class-hierarchy.py PySide > pyside.list
# ./list-class-hierarchy.py PyQt4 > pyqt4.list
#
# meld pyside.list pyqt4.list

import sys
import pdb
from inspect import isclass

ignore = ["staticMetaObject",
          "pyqtConfigure",
          "registerUserData",
          "thread",
         ]

def recurse_into(el,obj):
    #s = el.split('.')[-1]
    #pdb.set_trace()
    symbols = []
    for item in sorted(dir(obj)):
        if item[0]=='_':
            continue
        mel = el + '.' + item
        try:
            mobj = eval(mel)
        except Exception:
            continue

        if item in ignore:
            continue
        else:
            symbols.append(mel)

        if isclass(mobj):
            symbols += recurse_into(mel,mobj)

    return symbols

if __name__=='__main__':
    modules = [ 'QtCore',
                'QtGui',
                'QtHelp',
               #'QtMultimedia',
                'QtNetwork',
                'QtOpenGL',
                'QtScript',
                'QtScriptTools',
                'QtSql',
                'QtSvg',
                'QtTest',
               #'QtUiTools',
                'QtWebKit',
                'QtXml',
                'QtXmlPatterns' ]

    libraries = ["PySide", "PyQt4"]
    librarySymbols = {}
    for l in libraries:
        dictionary = []
        if l =="PyQt4":
            import sip
            sip.setapi('QDate',2)
            sip.setapi('QDateTime',2)
            sip.setapi('QString',2)
            sip.setapi('QTextStream',2)
            sip.setapi('QTime',2)
            sip.setapi('QUrl',2)
            sip.setapi('QVariant',2)

        for m in modules:
            exec "from %s import %s" % (l,m) in globals(), locals()
            dictionary += recurse_into(m, eval(m))
        librarySymbols[l] = dictionary

    print "PyQt4: ", len(librarySymbols["PyQt4"]), " PySide: ", len(librarySymbols["PySide"])

    for symbol in librarySymbols["PyQt4"]:
        if not (symbol in librarySymbols["PySide"]):
            print "Symbol not found in PySide:", symbol



from PySide.QtGui import *

if __name__ == '__main__':
    app = QApplication([])

    wdg = QWidget()

    hbox = QHBoxLayout()

    vbox = QVBoxLayout()
    vbox.addLayout(hbox)

    wdg.setLayout(vbox)



#!/usr/bin/python

'''Test cases for QTimer.singleShot'''

import unittest

from PySide.QtCore import QObject, QTimer, QCoreApplication, SIGNAL
from helper import UsesQCoreApplication

class TestDeleteLater(UsesQCoreApplication):
    '''Test case for function DeleteLater'''

    def testCase(self):
        o = QObject()
        o.deleteLater()
        del o
        QTimer.singleShot(100, self.app.quit)
        self.app.exec_()

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
'''Test cases for QObject protected methods'''

import unittest

from PySide.QtCore import QObject, QThread, SIGNAL

class Dummy(QObject):
    '''Dummy class'''
    pass

class QObjectReceivers(unittest.TestCase):
    '''Test case for QObject.receivers()'''

    def cb(self, *args):
        #Dummy callback
        pass

    def testQObjectReceiversExtern(self):
        #QObject.receivers() - Protected method external access

        obj = Dummy()
        self.assertEqual(obj.receivers(SIGNAL("destroyed()")), 0)

        QObject.connect(obj, SIGNAL("destroyed()"), self.cb)
        self.assertEqual(obj.receivers(SIGNAL("destroyed()")), 1)

    def testQThreadReceiversExtern(self):
        #QThread.receivers() - Inherited protected method

        obj = QThread()
        self.assertEqual(obj.receivers(SIGNAL('destroyed()')), 0)
        QObject.connect(obj, SIGNAL("destroyed()"), self.cb)
        self.assertEqual(obj.receivers(SIGNAL("destroyed()")), 1)


if __name__ == '__main__':
    unittest.main()



import sys
from PySide.QtCore import *
from PySide.QtGui import *

class ListModel(QAbstractListModel):
    def rowCount(self, parent = QModelIndex()):
        return 0

app = QApplication([])
model = ListModel()
v = QListView()
v.setModel(model)
QTimer.singleShot(0, v.close)
app.exec_()



#!/usr/bin/python

import unittest
from PySide.QtCore import QRegExp

class QRegExpTest(unittest.TestCase):

    def testReplace1(self):
        re = QRegExp('a[mn]')
        string = re.replace('Banana', 'ox')
        self.assertEqual(string, 'Boxoxa')

    def testReplace2(self):
        re = QRegExp('<i>([^<]*)</i>')
        string = re.replace('A <i>bon mot</i>.', '\\emph{\\1}')
        self.assertEqual(string, 'A \\emph{bon mot}.')

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import Qt
from PySide.QtGui import QKeySequence

from helper import UsesQApplication

class QKeySequenceTest(UsesQApplication):

    def testGetItemOperator(self):
        # bug #774
        ks = QKeySequence(Qt.SHIFT, Qt.CTRL, Qt.Key_P, Qt.Key_R)
        self.assertEqual(ks[0], Qt.SHIFT)
        self.assertEqual(ks[1], Qt.CTRL)
        self.assertEqual(ks[2], Qt.Key_P)
        self.assertEqual(ks[3], Qt.Key_R)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from PySide.QtCore import QObject, QState, QFinalState, SIGNAL
from PySide.QtCore import QTimer, QStateMachine
from PySide.QtCore import QParallelAnimationGroup

from helper import UsesQCoreApplication


class StateMachineTest(unittest.TestCase):
    '''Check presence of State Machine classes'''

    def testBasic(self):
        '''State machine classes'''
        import PySide.QtCore
        PySide.QtCore.QSignalTransition
        PySide.QtCore.QPropertyAnimation



class QStateMachineTest(UsesQCoreApplication):

    def cb(self, *args):
        self.assertEqual(self.machine.defaultAnimations(), [self.anim])

    def testBasic(self):
        self.machine = QStateMachine()
        s1 = QState()
        s2 = QState()
        s3 = QFinalState()

        QObject.connect(self.machine, SIGNAL("started()"), self.cb)

        self.anim = QParallelAnimationGroup()

        self.machine.addState(s1)
        self.machine.addState(s2)
        self.machine.addState(s3)
        self.machine.setInitialState(s1)
        self.machine.addDefaultAnimation(self.anim)
        self.machine.start()

        QTimer.singleShot(100, self.app.quit)
        self.app.exec_()


class QSetConverterTest(UsesQCoreApplication):
    '''Test converter of QSet toPython using QStateAnimation.configuration'''

    def testBasic(self):
        '''QStateMachine.configuration converting QSet to python set'''
        machine = QStateMachine()
        s1 = QState()
        machine.addState(s1)
        machine.setInitialState(s1)
        machine.start()

        QTimer.singleShot(100, self.app.quit)
        self.app.exec_()

        configuration = machine.configuration()

        self.assert_(isinstance(configuration, set))
        self.assert_(s1 in configuration)


if __name__ == '__main__':
    unittest.main()



# This file is part of PySide: Python for Qt
#
# Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
#
# Contact: PySide team <contact@pyside.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA

import unittest
import sys
import os


if sys.platform == 'win32':
    from PySide._utils import _get_win32_case_sensitive_name

    class Win32UtilsTest(unittest.TestCase):
        def testWin32CaseSensitiveName(self):
            from tempfile import mkdtemp
            caseSensitiveName = 'CaseSensitiveName'
            tmpdir = mkdtemp(caseSensitiveName)
            try:
                path = _get_win32_case_sensitive_name(tmpdir.lower())
                self.assertTrue(path.endswith(caseSensitiveName))
            finally:
                if os.path.exists(tmpdir):
                    os.rmdir(tmpdir)


if __name__ == '__main__':
    unittest.main()



''' unit test for BUG #1060 '''

from PySide.QtGui import QApplication
from PySide.QtUiTools import QUiLoader
from helper import adjust_filename

class MyQUiLoader(QUiLoader):
    def __init__(self):
        super(MyQUiLoader, self).__init__()

    def createWidget(self, *args):
        return super(MyQUiLoader, self).createWidget(*args)

if __name__ == "__main__":
    app = QApplication([])

    ui = MyQUiLoader().load(adjust_filename("bug_1060.ui", __file__))
    ui.show()



#!/usr/bin/python
'''Unit tests for static protected methods'''

import unittest, time

from PySide.QtCore import QThread

class Test (QThread):
    def run(self):
        start = time.time()
        self.sleep(1)
        self.time_elapsed = time.time() - start

class QStaticProtectedCall(unittest.TestCase):
    '''Test case for static protected method call'''

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPathSeparator(self):
        thread = Test()
        thread.start()
        thread.wait()
        self.assertTrue(thread.time_elapsed <= 1.1) # tolarance of 100ms

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtGui import QApplication, QLCDNumber

class QLCDNumberOverflow(unittest.TestCase):
    '''Test case for unhandled overflow on QLCDNumber() numDigits argument (see bug #215).'''

    def setUp(self):
        self.app = QApplication([])

    def testnumDigitsOverflow(self):
        # NOTE: PyQt4 raises TypeError, but boost.python raises OverflowError
        self.assertRaises(OverflowError, QLCDNumber, 840835495615213080)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import QPointF
from PySide.QtGui import QTransform, QPolygonF, QPolygonF

class QTransformTest(unittest.TestCase):

    def testMap(self):
        transform = QTransform()
        values = (10.0, 20.0)
        tx, ty = transform.map(*values)
        self.assert_(isinstance(tx, float))
        self.assert_(isinstance(ty, float))
        self.assertEqual((tx, ty), values)

    def testquadToQuad(self):
        q1 = QPolygonF()
        q1.append(QPointF(10.0, 10.0))
        q1.append(QPointF(20.0, 10.0))
        q1.append(QPointF(10.0, -10.0))
        q1.append(QPointF(20.0, -10.0))

        q2 = QPolygonF()
        q2.append(QPointF(20.0, 20.0))
        q2.append(QPointF(30.0, 20.0))
        q2.append(QPointF(20.0, -20.0))
        q2.append(QPointF(30.0, -20.0))

        t1 = QTransform()
        r1 = QTransform.quadToQuad(q1, q2, t1)
        r2 = QTransform.quadToQuad(q1, q2)

        self.assertTrue(r1)
        self.assert_(r2)

        self.assertEqual(t1, r2)

    def testquadToSquare(self):
        q1 = QPolygonF()
        q1.append(QPointF(10.0, 10.0))
        q1.append(QPointF(20.0, 10.0))
        q1.append(QPointF(10.0, -10.0))
        q1.append(QPointF(20.0, -10.0))

        t1 = QTransform()
        r1 = QTransform.quadToSquare(q1, t1)
        r2 = QTransform.quadToSquare(q1)

        self.assertTrue(r1)
        self.assert_(r2)

        self.assertEqual(t1, r2)


    def testsquareToQuad(self):
        q1 = QPolygonF()
        q1.append(QPointF(10.0, 10.0))
        q1.append(QPointF(20.0, 10.0))
        q1.append(QPointF(10.0, -10.0))
        q1.append(QPointF(20.0, -10.0))

        t1 = QTransform()
        r1 = QTransform.squareToQuad(q1, t1)
        r2 = QTransform.squareToQuad(q1)

        self.assertTrue(r1)
        self.assert_(r2)

        self.assertEqual(t1, r2)


if __name__ == "__main__":
   unittest.main()




#!/usr/bin/python

import unittest
from helper import TimedQApplication
from PySide.QtCore import QSignalTransition, QState, Qt, QStateMachine
from PySide.QtGui import QCheckBox

class CheckedTransition(QSignalTransition):
    def __init__(self, check):
        QSignalTransition.__init__(self, check.stateChanged[int])
        self.eventTested = False

    def eventTest(self, event):
        self.eventTested = True
        if not QSignalTransition.eventTest(self, event):
            return False
        return event.arguments()[0] == Qt.Checked

class TestBug(TimedQApplication):
    def testCase(self):
        check = QCheckBox()
        check.setTristate(True)

        s1 = QState()
        s2 = QState()

        t1 = CheckedTransition(check)
        t1.setTargetState(s2)
        s1.addTransition(t1)

        machine = QStateMachine()
        machine.addState(s1)
        machine.addState(s2)
        machine.setInitialState(s1)
        machine.start()

        check.stateChanged[int].emit(1)
        check.show()
        self.app.exec_()
        self.assert_(t1.eventTested)

if __name__ == '__main__':
    unittest.main()




''' Test the presence of qApp Macro'''

import unittest

from PySide.QtGui import *

class QAppPresence(unittest.TestCase):

    def testQApp(self):
        #QtGui.qApp variable is instance of QApplication
        self.assert_(isinstance(qApp, QApplication))

def main():
    app = QApplication([])
    unittest.main()

if __name__ == '__main__':
    main()



import unittest
from PySide.QtGui import QApplication

class TestBug998 (unittest.TestCase):
    def testNoFocusWindow(self):
        widget = QApplication.focusWidget()
        self.assertTrue(widget == None)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide import QtGui, QtUiTools
from helper import adjust_filename
from helper import TimedQApplication

class Gui_Qt(QtGui.QMainWindow):
    def __init__(self, parent=None):
        super(Gui_Qt, self).__init__(parent)

        lLoader = QtUiTools.QUiLoader()

        # this used to cause a segfault because the old inject code used to destroy the parent layout
        self._cw = lLoader.load(adjust_filename('bug_958.ui', __file__),  self)

        self.setCentralWidget(self._cw)

class BugTest(TimedQApplication):
    def testCase(self):
        lMain = Gui_Qt()
        lMain.show()
        self.app.exec_()

if __name__ == "__main__":
    unittest.main()




import unittest

from PySide.QtGui import QTextLayout
from helper import UsesQApplication

class QTextLineTest(UsesQApplication):

    def testCursorToX(self):
        textLayout = QTextLayout()
        textLayout.beginLayout()
        line = textLayout.createLine()
        self.assert_(line.isValid())
        x, cursorPos = line.cursorToX(0)
        self.assertEqual(type(x), float)
        self.assertEqual(type(cursorPos), int)
        x, cursorPos = line.cursorToX(1)
        self.assertEqual(type(x), float)
        self.assertEqual(type(cursorPos), int)

if __name__ == '__main__':
    unittest.main()




from helper import adjust_filename
from PySide import QtGui, QtCore
from PySide.QtUiTools import QUiLoader

class View_1(QtGui.QWidget):

    def __init__(self):
        QtGui.QWidget.__init__(self)
        loader = QUiLoader()
        widget = loader.load(adjust_filename('bug_552.ui', __file__), self)
        self.children = []
        for child in widget.findChildren(QtCore.QObject, None):
            self.children.append(child)
        self.t = widget.tabWidget
        self.t.removeTab(0)

app = QtGui.QApplication([])
window = View_1()
window.show()

# If it doesn't crash it works :-)



import unittest

from PySide import QtCore, QtGui
from helper import UsesQApplication, TimedQApplication

class TestInputDialog(TimedQApplication):

    def testGetDouble(self):
        self.assertEquals(QtGui.QInputDialog.getDouble(None, "title", "label"), (0.0, False))

    def testGetInt(self):
        self.assertEquals(QtGui.QInputDialog.getInt(None, "title", "label"), (0, False))

    def testGetInteger(self):
        self.assertEquals(QtGui.QInputDialog.getInteger(None, "title", "label"), (0, False))

    def testGetItem(self):
        (item, bool) = QtGui.QInputDialog.getItem(None, "title", "label", ["1", "2", "3"])
        self.assertEquals(str(item), "1")

    def testGetText(self):
        (text, bool) = QtGui.QInputDialog.getText(None, "title", "label")
        self.assertEquals(str(text),"")

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtGui import QLayout, QWidget, QGraphicsLayout, QGraphicsLayoutItem, QTextCursor, QPrinter

from helper import UsesQApplication

class Layout(QLayout):
    def __init__(self):
        QLayout.__init__(self)

class GraphicsLayout(QGraphicsLayout):
    def __init__(self):
        QGraphicsLayout.__init__(self)

class GraphicsLayoutItem(QGraphicsLayoutItem):
    def __init__(self):
        QGraphicsLayoutItem.__init__(self)

class ReturnsQuadruplesOfNumbers(UsesQApplication):
    def compareTuples(self, ta, tb):
        for va,vb in zip(ta, tb):
            if round(va) != round(vb):
                return False
        return True

    def testQGraphicsLayoutGetContentsMargins(self):
        obj = GraphicsLayout()
        values = (10.0, 20.0, 30.0, 40.0)
        obj.setContentsMargins(*values)
        self.assert_(self.compareTuples(obj.getContentsMargins(), values))

    def testQGraphicsLayoutItemGetContentsMargins(self):
        obj = GraphicsLayoutItem()
        self.assert_(self.compareTuples(obj.getContentsMargins(), (0.0, 0.0, 0.0, 0.0)))

    def testQWidgetGetContentsMargins(self):
        obj = QWidget()
        values = (10, 20, 30, 40)
        obj.setContentsMargins(*values)
        self.assert_(self.compareTuples(obj.getContentsMargins(), values))

    def testQLayoutGetContentsMargins(self):
        obj = Layout()
        values = (10, 20, 30, 40)
        obj.setContentsMargins(*values)
        self.assert_(self.compareTuples(obj.getContentsMargins(), values))

    def testQTextCursorSelectedTableCells(self):
        obj = QTextCursor()
        self.assertEquals(obj.selectedTableCells(), (-1, -1, -1, -1))

    def testQPrinterGetPageMargins(self):
        # Bug #742
        obj = QPrinter()
        values = (10.0, 20.0, 30.0, 40.0, QPrinter.Point)
        obj.setPageMargins(*values)
        self.assert_(self.compareTuples(obj.getPageMargins(QPrinter.Point), values[:-1]))

if __name__ == "__main__":
   unittest.main()




from PySide.QtCore import *

import unittest

get_counter = 0
set_counter = 0

class Descriptor(object):
    def __get__(self, obj, owner):
        global get_counter

        if not obj:
            return self

        get_counter += 1
        return obj.var

    def __set__(self, obj, value):
        global set_counter

        set_counter += 1
        obj.var = value

class FooBar(QObject):
    test = Descriptor()
    var = 0

class SetAndGetTestCases(unittest.TestCase):
    def setUp(self):
        global get_counter
        global set_counter

        get_counter = 0
        set_counter = 0

    def testSetMethod(self):
        global get_counter
        global set_counter

        f = FooBar()

        f.test = 1
        self.assertEqual(get_counter, 0)
        self.assertEqual(set_counter, 1)

        get_counter = 0
        set_counter = 0

    def testGetMethod(self):
        global get_counter
        global set_counter

        f = FooBar()
        f.test = 1
        set_counter = 0

        ret = f.test
        self.assertEqual(get_counter, 1)
        self.assertEqual(set_counter, 0)

        get_counter = 0
        set_counter = 0

if __name__ == "__main__":
    unittest.main()




import unittest

from PySide.QtCore import QObject, SIGNAL

# Description of the problem
# After creating an PyObject that inherits from QObject, connecting it,
# deleting it and later creating another Python QObject-based object, this
# new object will point to the same memory position as the first one.

# Somehow the underlying QObject also points to the same position.

# In PyQt4, the connection works fine with the same memory behavior,
# so it looks like specific to SIP.

class Dummy(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)

class Joe(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)

class SegfaultCase(unittest.TestCase):
    """Test case for the segfault happening when parent() is called inside
    ProxyObject"""

    def setUp(self):
        self.called = False

    def tearDown(self):
        try:
            del self.args
        except:
            pass

    def callback(self, *args):
        if tuple(self.args) == args:
            self.called = True

    def testSegfault(self):
        """Regression: Segfault for qobjects in the same memory position."""
        obj = Dummy()
        QObject.connect(obj, SIGNAL('bar(int)'), self.callback)
        self.args = (33,)
        obj.emit(SIGNAL('bar(int)'), self.args[0])
        self.assert_(self.called)
        del obj

        obj = Joe()
        QObject.connect(obj, SIGNAL('bar(int)'), self.callback)
        self.args = (33,)
        obj.emit(SIGNAL('bar(int)'), self.args[0])
        self.assert_(self.called)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python

import unittest
from PySide.QtCore import QObject
from testbinding import TestObject

class Receiver(QObject):
    def __init__(self):
        QObject.__init__(self)
        self.called = False

    def ReceiverDecorator(func):
        def decoratedFunction(self, *args, **kw):
            func(self, *args, **kw)
        return decoratedFunction

    # This method with the same name of the internal decorated function
    # is here to test the binding capabilities.
    def decoratedFunction(self):
        pass

    @ReceiverDecorator
    def slot(self):
        self.called = True


class DecoratedSlotTest(unittest.TestCase):

    def testCallingOfDecoratedSlot(self):
        obj = TestObject(0)
        receiver = Receiver()
        obj.staticMethodDouble.connect(receiver.slot)
        obj.emitStaticMethodDoubleSignal()
        self.assert_(receiver.called)


if __name__ == '__main__':
    unittest.main()




''' Test bug 635: http://bugs.openbossa.org/show_bug.cgi?id=635'''

import unittest
from PySide.QtGui import QApplication, QToolBar, QIcon
import sys

class testQToolBar(unittest.TestCase):
    def callback(self):
        self._called = True

    def testAddAction(self):
        bar = QToolBar()
        self._called = False
        a = bar.addAction("act1", self.callback)
        a.trigger()
        self.assert_(self._called)

    def testAddActionWithIcon(self):
        bar = QToolBar()
        self._called = False
        icon = QIcon()
        a = bar.addAction(icon, "act1", self.callback)
        a.trigger()
        self.assert_(self._called)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    unittest.main()




'''Test cases for QWebView'''

import unittest
import py3kcompat as py3k
import sys

from PySide.QtCore import QObject, SIGNAL, QUrl
from PySide.QtWebKit import QWebPage, QWebView
from PySide.QtNetwork import QNetworkRequest

from helper import adjust_filename, TimedQApplication


class testWebPage(QWebPage):
    def sayMyName(self):
        return 'testWebPage'

class TestLoadFinished(TimedQApplication):
    '''Test case for signal QWebView.loadFinished(bool)'''

    def setUp(self):
        #Acquire resources
        TimedQApplication.setUp(self, timeout=1000)
        self.view = QWebView()
        QObject.connect(self.view, SIGNAL('loadFinished(bool)'),
                        self.load_finished)
        self.called = False

    def tearDown(self):
        #Release resources
        del self.view
        self.called = False
        TimedQApplication.tearDown(self)

    def testLoadFinishedFromFile(self):
        url = QUrl.fromLocalFile(adjust_filename('fox.html', __file__))
        self.view.setUrl(url)
        self.app.exec_()

        self.assert_(self.called)

    def testSetPageAndGetPage(self):
        twp = testWebPage()
        self.view.setPage(twp)
        del twp
        p = self.view.page()
        self.assertEqual(p.sayMyName(), 'testWebPage')

        # Setting the same webpage should not incref the python obj
        refCount = sys.getrefcount(p)
        self.view.setPage(p)
        self.assertEquals(sys.getrefcount(p), refCount)

        # Changing the webpage obj should decref the old one
        twp2 = testWebPage()
        self.view.setPage(twp2)
        self.assertEquals(sys.getrefcount(p), refCount - 1)

    def load_finished(self, ok):
        #Callback to check if load was successful
        self.app.quit()
        if ok:
            self.called = True

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import QObject, SIGNAL

class MyObject(QObject):
    pass


class TestSignalLimitless(unittest.TestCase):
    SIGNAL_MAX = 100
    def test100DynamicSignals(self):

        self.count = 0
        def onSignal():
            self.count += 1

        #create 100 dynamic signals
        o = MyObject()
        for i in range(self.SIGNAL_MAX):
            o.connect(SIGNAL('sig%d()'%i), onSignal)

        #chek if the signals are valid
        m = o.metaObject()
        for i in range(self.SIGNAL_MAX):
            self.assert_(m.indexOfSignal('sig%d()'%i) > 0)

        #emit all 100 signals
        for i in range(self.SIGNAL_MAX):
            o.emit(SIGNAL('sig%d()'%i))

        self.assertEqual(self.count, self.SIGNAL_MAX)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from sys import getrefcount
from PySide.QtCore import QBuffer
from PySide.QtSvg import QSvgGenerator

class QSvgGeneratorTest(unittest.TestCase):

    def testRefCountOfTOutputDevice(self):
        generator = QSvgGenerator()
        iodevice1 = QBuffer()
        refcount1 = getrefcount(iodevice1)

        generator.setOutputDevice(iodevice1)

        self.assertEqual(generator.outputDevice(), iodevice1)
        self.assertEqual(getrefcount(generator.outputDevice()), refcount1 + 1)

        iodevice2 = QBuffer()
        refcount2 = getrefcount(iodevice2)

        generator.setOutputDevice(iodevice2)

        self.assertEqual(generator.outputDevice(), iodevice2)
        self.assertEqual(getrefcount(generator.outputDevice()), refcount2 + 1)
        self.assertEqual(getrefcount(iodevice1), refcount1)

        del generator

        self.assertEqual(getrefcount(iodevice2), refcount2)

if __name__ == '__main__':
    unittest.main()




def b(s):
    if type(s) == bytes:
        return s
    return bytes(s, "UTF8")

def buffer_(s):
    if s == None:
        return None
    elif type(s) == str:
        return bytes(s, "UTF8")
    elif type(s) == bytes:
        return s
    else:
        memoryview(s)

def l(n):
    return n

def unicode_(s):
    return s

unicode = str
unichr = chr
long = int
unichr = chr
buffer = buffer_



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide.QtCore import QCoreApplication, QTimeLine
from helper import UsesQCoreApplication

class NativeSignalsTest(UsesQCoreApplication):

    def setUp(self):
        UsesQCoreApplication.setUp(self)
        self.called = False
        self.timeline = QTimeLine(100)

    def tearDown(self):
        del self.called
        del self.timeline
        UsesQCoreApplication.tearDown(self)

    def testSignalWithIntArgument(self):

        def valueChangedSlot(value):
            self.called = True
            self.assertEqual(type(value), float)
            self.app.quit()

        self.timeline.valueChanged.connect(valueChangedSlot)
        self.timeline.start()

        self.app.exec_()
        self.assert_(self.called)

    def testSignalWithoutArguments(self):

        def finishedSlot():
            self.called = True
            self.app.quit()

        self.timeline.finished.connect(finishedSlot)
        self.timeline.start()

        self.app.exec_()
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()





import unittest

import os
import tempfile
import py3kcompat as py3k

from PySide.QtCore import QFile, QIODevice

class GetCharTest(unittest.TestCase):
    '''Test case for QIODevice.getChar in QFile'''

    def setUp(self):
        '''Acquire resources'''
        handle, self.filename = tempfile.mkstemp()
        os.write(handle, py3k.b('a'))
        os.close(handle)

    def tearDown(self):
        '''release resources'''
        os.remove(self.filename)

    def testBasic(self):
        '''QFile.getChar'''
        obj = QFile(self.filename)
        obj.open(QIODevice.ReadOnly)
        self.assertEqual(obj.getChar(), (True, 'a'))
        self.assertFalse(obj.getChar()[0])
        obj.close()

    def testBug721(self):
        obj = QFile(self.filename)
        obj.open(QIODevice.ReadOnly)
        memory = obj.map(0, 1)
        self.assertEqual(len(memory), 1)
        self.assertEqual(memory[0], py3k.b('a'))
        obj.unmap(memory)
        # now memory points to wild bytes... :-)
        # uncommenting this must cause a segfault.
        # self.assertEqual(memory[0], 'a')

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import QObject
from PySide.QtGui import QInputDialog

from helper import UsesQApplication

class DynamicSignalTest(UsesQApplication):

    def cb(self, obj):
        self._called = True

    def testQDialog(self):
        dlg = QInputDialog()
        dlg.setInputMode(QInputDialog.TextInput)
        lst = dlg.children()
        self.assert_(len(lst))
        obj = lst[0]
        self._called = False
        obj.destroyed[QObject].connect(self.cb)
        obj = None
        del dlg
        self.assert_(self._called)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import unittest

from PySide.QtCore import *
from PySide.QtGui import *
from helper import UsesQApplication

class NeverDiesTest(UsesQApplication):

    def testIt(self):
        QPrintDialog()

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python

import unittest

import PySide.QtCore as QtCore
import PySide.QtGui as QtGui

from helper import TimedQApplication

class Signaller(QtCore.QObject):
    s1 = QtCore.Signal()
    s2 = QtCore.Signal()
    s3 = QtCore.Signal()

class Window(object):

    def __init__(self, s):
        self._window = QtGui.QMainWindow()
        self._window.setAttribute(QtCore.Qt.WA_DeleteOnClose, True)
        self._window.setWindowTitle("Demo!")

        self._s = s
        self._s.s1.connect(self._on_signal)
        self._s.s2.connect(self._on_signal)

    def show(self):
        self._window.show()

    def _on_signal(self):
        self._window.setWindowTitle("Signaled!")

class TestTimedApp(TimedQApplication):
    def testSignals(self):
        s = Signaller()
        w = Window(s)
        w.show()

        def midleFunction():
            def internalFunction():
                pass
            s.s3.connect(internalFunction)

        midleFunction()
        self.app.exec_()
        del w

        s.s1.emit()
        s.s2.emit()
        s.s3.emit()

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

import unittest
from testbinding import Enum1, TestObjectWithoutNamespace

class ListConnectionTest(unittest.TestCase):

    def testEnumVisibility(self):
        self.assertEqual(Enum1.Option1, 1)
        self.assertEqual(Enum1.Option2, 2)
        self.assertEqual(TestObjectWithoutNamespace.Enum2.Option3, 3)
        self.assertEqual(TestObjectWithoutNamespace.Enum2.Option4, 4)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
'''Unit tests for QLocale'''

import unittest
import ctypes
import sys

from PySide.QtCore import QLocale

class QLocaleTestToNumber(unittest.TestCase):
    def testToNumberInt(self):
        obj = QLocale(QLocale.C)
        self.assertEqual((37, True), obj.toInt('37'))

    def testToNumberFloat(self):
        obj = QLocale(QLocale.C)
        self.assertEqual((ctypes.c_float(37.109).value, True),
                         obj.toFloat('37.109'))

    def testToNumberDouble(self):
        obj = QLocale(QLocale.C)
        self.assertEqual((ctypes.c_double(37.109).value, True),
                         obj.toDouble('37.109'))

    def testToNumberShort(self):
        obj = QLocale(QLocale.C)
        self.assertEqual((ctypes.c_short(37).value, True),
                         obj.toShort('37'))

    def testToNumberULongLong(self):
        obj = QLocale(QLocale.C)
        self.assertEqual((ctypes.c_ulonglong(37).value, True),
                         obj.toULongLong('37'))

    def testToNumberULongLongNegative(self):
        obj = QLocale(QLocale.C)
        self.assert_(not obj.toULongLong('-37')[1])

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Tests the presence of unary operator __neg__ on the QPoint class'''

import unittest

from PySide.QtCore import QPoint

class NegUnaryOperatorTest(unittest.TestCase):
    '''Tests the presence of unary operator __neg__ on the QPoint class'''

    def setUp(self):
        #Acquire resources
        self.x, self.y = 10, 20
        self.neg_x, self.neg_y = -self.x, -self.y
        self.qpoint = QPoint(self.x, self.y)

    def tearDown(self):
        #Release resources
        del self.qpoint
        del self.x
        del self.y
        del self.neg_x
        del self.neg_y

    def testNegUnaryOperator(self):
        #Test __neg__ unary operator on QPoint class
        __neg__method_exists = True
        try:
            neg_qpoint = -self.qpoint
        except:
            __neg__method_exists = False

        self.assertTrue(__neg__method_exists)
        self.assertEqual(self.qpoint, -neg_qpoint)

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtCore import QSysInfo

class TestQSysInfo(unittest.TestCase):
    def testEnumEndian(self):
        self.assertEqual(QSysInfo.BigEndian, 0)
        self.assertEqual(QSysInfo.LittleEndian, 1)
        self.assert_(QSysInfo.ByteOrder > -1)

    def testEnumSizes(self):
        self.assert_(QSysInfo.WordSize > 0)

if __name__ == '__main__':
    unittest.main()




import os
import unittest
from PySide.phonon import Phonon
from helper import UsesQCoreApplication

sample_file = os.path.join(os.path.dirname(__file__), 'tone.wav')

def checkBackendCapabilities(func):
    def function(self, *args, **kw):
        if Phonon.BackendCapabilities.isMimeTypeAvailable('audio/x-wav'):
            func(self, *args, **kw)
        else:
            print('Wav format not supported! Playback test skipped!')
    return function


class TestSimplePlaying(UsesQCoreApplication):
    def setUp(self):
        super(TestSimplePlaying, self).setUp()
        self.app.setApplicationName('Dummy')
        self.source = Phonon.MediaSource(sample_file)
        self.media = Phonon.MediaObject()
        self.media.setCurrentSource(self.source)

        self.media.finished.connect(self.app.quit)
        self.called = False

        # prevent locking with:
        # request to play a stream, but no valid audio ...
        self.output = Phonon.AudioOutput()
        self.path = Phonon.createPath(self.media, self.output)

    def tearDown(self):
        super(TestSimplePlaying, self).tearDown()
        del self.path
        del self.output
        del self.media
        del self.source

    @checkBackendCapabilities
    def testFinishedSignal(self):
        # Should pass if finished() is called
        self.media.play()
        self.app.exec_()

    def testMediaSource(self):
        self.assertEqual(self.media.currentSource(), self.source)

    def testPathCreation(self):
        # FIXME Both functions below are not exported by PyQt4
        self.assertEqual(self.path.sink(), self.output)
        self.assertEqual(self.path.source(), self.media)

    def state_cb(self, newState, OldState):
        self.called = True

    @checkBackendCapabilities
    def testStateChanged(self):
        self.media.stateChanged['Phonon::State', 'Phonon::State'].connect(self.state_cb)
        self.media.play()
        self.app.exec_()
        self.assertTrue(self.called)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test case for the bug #378
http://bugs.openbossa.org/show_bug.cgi?id=378
'''

import unittest
from PySide.QtCore import QObject

class ExtQObject(QObject):
    def __init__(self):
        # "foobar" will become a object attribute that will not be
        # listed on the among the type attributes. Thus for bug
        # condition be correctly triggered the "foobar" attribute
        # must not previously exist in the parent class.
        self.foobar = None
        # The parent __init__ method must be called after the
        # definition of "self.foobar".
        QObject.__init__(self)

class TestBug378(unittest.TestCase):
    '''Test case for the bug #378'''

    def testBug378(self):
        obj = ExtQObject()

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python

from PySide import QtCore, QtGui
from PySide.phonon import Phonon
import unittest

class TestBug(unittest.TestCase):
    def myCB(self):
        pass

    def testForNotifierSignals(self):
        # this test only check if the signals are present
        notifier = Phonon.BackendCapabilities.Notifier()
        notifier.capabilitiesChanged.connect(self.myCB)
        notifier.availableAudioOutputDevicesChanged.connect(self.myCB)

        self.assert_(True)





'''Script to show the difference between PyQt4 and ours'''

import sys

from color import print_colored

def check_module_diff(module_name):
    '''Difference between PySide and PyQt4 versions of qt bindings.
    Returns a tuple with the members present only on PySide and only on PyQt4'''
    boost_module = getattr(__import__('PySide.' + module_name), module_name)
    orig_module = getattr(__import__('PyQt4.' + module_name), module_name)

    boost_set = set(dir(boost_module))
    orig_set = set(dir(orig_module))

    return sorted(boost_set - orig_set), sorted(orig_set - boost_set)


def main(argv=None):
    if argv is None:
        argv = sys.argv

    module_name = argv[1] if len(argv) >= 2 else 'QtCore'

    only_boost, only_orig = check_module_diff(module_name)

    print_colored('Only on Boost version')
    print only_boost

    print_colored('Only on SIP version')
    print only_orig

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

import unittest
import sys

from PySide.QtCore import QDataStream, QByteArray, QIODevice, Qt
from PySide.QtGui import QPixmap, QColor

from helper import UsesQApplication

class QPixmapQDatastream(UsesQApplication):
    '''QDataStream <<>> QPixmap'''

    def setUp(self):
        super(QPixmapQDatastream, self).setUp()
        self.source_pixmap = QPixmap(100, 100)
        self.source_pixmap.fill(Qt.red)
        self.output_pixmap = QPixmap()
        self.buffer = QByteArray()
        self.read_stream = QDataStream(self.buffer, QIODevice.ReadOnly)
        self.write_stream = QDataStream(self.buffer, QIODevice.WriteOnly)

    def testStream(self):
        self.write_stream << self.source_pixmap

        self.read_stream >> self.output_pixmap

        image = self.output_pixmap.toImage()
        pixel = image.pixel(10,10)
        self.assertEqual(pixel, QColor(Qt.red).rgba())
        self.assertEqual(self.source_pixmap.toImage(), self.output_pixmap.toImage())


if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *
import unittest


class TestBug569(unittest.TestCase):

    def testIt(self):
        types = (QTableWidgetItem, QListWidgetItem, QTreeWidgetItem)
        for t in types:
            a = t()
            a.__lt__ = lambda other : True
            b = t()
            b.__lt__ = lambda other : False
            self.assertTrue(a < b)
            self.assertFalse(b < a)

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtGui import QAction, QWidget
from helper import UsesQApplication

class QPainterDrawText(UsesQApplication):

    def _cb(self):
        self._called = True

    def testSignal(self):
        o = QWidget()
        act = QAction(o)
        self._called = False
        act.triggered.connect(self._cb)
        act.trigger()
        self.assert_(self._called)

    def testNewCtor(self):
        o = QWidget()
        self._called = False
        myAction = QAction("&Quit", o, triggered=self._cb)
        myAction.trigger()
        self.assert_(self._called)


class SetShortcutTest(UsesQApplication):

    def testSetShortcut(self):
        # Somehow an exception was leaking from the constructor
        # and appearing in setShortcut.
        o = QWidget()
        action = QAction('aaaa', o)
        shortcut = 'Ctrl+N'
        action.setShortcut(shortcut)
        s2 = action.shortcut()
        self.assertEqual(s2, shortcut)

if __name__ == '__main__':
    unittest.main()




''' Test bug 451: http://bugs.openbossa.org/show_bug.cgi?id=451'''

from PySide import QtCore, QtGui, QtDeclarative
from helper import adjust_filename
import sys
import unittest

class PythonObject(QtCore.QObject):
    def __init__(self):
        QtCore.QObject.__init__(self, None)
        self._called = ""
        self._arg1 = None
        self._arg2 = None

    def setCalled(self, v):
        self._called = v

    def setArg1(self, v):
        self._arg1 = v

    def setArg2(self, v):
        self._arg2 = v

    def getCalled(self):
        return self._called

    def getArg1(self):
        return self._arg1

    def getArg2(self):
        return self._arg2

    called = QtCore.Property(str, getCalled, setCalled)
    arg1 = QtCore.Property(int, getArg1, setArg1)
    arg2 = QtCore.Property('QVariant', getArg2, setArg2)

class TestBug(unittest.TestCase):
    def testQMLFunctionCall(self):
        app = QtGui.QApplication(sys.argv)
        view = QtDeclarative.QDeclarativeView()

        obj = PythonObject()
        context = view.rootContext()
        context.setContextProperty("python", obj)
        view.setSource(QtCore.QUrl.fromLocalFile(adjust_filename('bug_451.qml', __file__)))
        root = view.rootObject()
        root.simpleFunction()
        self.assertEqual(obj.called, "simpleFunction")

        root.oneArgFunction(42)
        self.assertEqual(obj.called, "oneArgFunction")
        self.assertEqual(obj.arg1, 42)

        root.twoArgFunction(10, app)
        self.assertEqual(obj.called, "twoArgFunction")
        self.assertEqual(obj.arg1, 10)
        self.assertEqual(obj.arg2, app)

        rvalue = root.returnFunction()
        self.assertEqual(obj.called, "returnFunction")
        self.assertEqual(rvalue, 42)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import unittest

from PySide import QtCore
from PySide import QtGui
from helper import UsesQApplication

class Item(QtGui.QGraphicsItem):
    
    def __init__(self):
        QtGui.QGraphicsItem.__init__(self)

    def boundingRect(self):
        return QtCore.QRectF(0, 0, 100, 100)
    
    def paint(self, painter, option, widget):
        painter.setBrush(QtGui.QColor(255, 255, 255))
        painter.drawRect(0, 0, 100, 100)


class QGraphicsViewIsBlockedTest(UsesQApplication):

    def testIsBlockedByModalPanel(self):
        (first, second) = Item().isBlockedByModalPanel()
        self.assertFalse(first)

if __name__ == "__main__":
    unittest.main()



import unittest
from PySide.QtCore import *
from PySide.QtGui import *

class TestBug964 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])
        model = QStringListModel(["1", "2"])
        view = QListView()
        view.setModel(model)
        view.setCurrentIndex(model.index(0,0))
        newCursor = view.moveCursor(QAbstractItemView.MoveDown, Qt.NoModifier)
        self.assertEqual(newCursor.row(), 1)
        self.assertEqual(newCursor.column(), 0)

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python

import unittest
from PySide.QtCore import *
from PySide.QtXmlPatterns import QXmlSchema
from helper import UsesQCoreApplication

class QXmlPatternsTest(UsesQCoreApplication):

    def testSchema(self):
        data = QByteArray('''<?xml version=\"1.0\" encoding=\"UTF-8\"?>
                              <xsd:schema
                                 xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\"
                                  xmlns=\"http://qt.nokia.com/xmlschematest\"
                                  targetNamespace=\"http://qt.nokia.com/xmlschematest\"
                                  version=\"1.0\"
                                  elementFormDefault=\"qualified\">
                              </xsd:schema>''')

        buf = QBuffer(data)
        buf.open(QIODevice.ReadOnly)

        schema = QXmlSchema()
        schema.load(buf)
        self.assert_(schema.isValid())


if __name__ == '__main__':
    unittest.main()





import unittest
from helper import UsesQApplication

from PySide.QtGui import QWidget, QLabel, QFontComboBox, QStyleFactory

class SetStyleTest(UsesQApplication):
    '''Tests setting the same QStyle for all objects in a UI hierarchy.'''

    def testSetStyle(self):
        '''All this test have to do is not break with some invalid Python wrapper.'''

        def setStyleHelper(widget, style):
            widget.setStyle(style)
            widget.setPalette(style.standardPalette())
            for child in widget.children():
                if isinstance(child, QWidget):
                    setStyleHelper(child, style)

        container = QWidget()
        # QFontComboBox is used because it has an QLineEdit created in C++ inside it,
        # and if the QWidget.setStyle(style) steals the ownership of the style
        # for the C++ originated widget everything will break.
        fontComboBox = QFontComboBox(container)
        label = QLabel(container)
        label.setText('Label')
        style = QStyleFactory.create(QStyleFactory.keys()[0])
        setStyleHelper(container, style)

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtCore import *

class TestBug938 (unittest.TestCase):

    def testIt(self):
        b = QBuffer()
        b.open(QBuffer.WriteOnly)
        b.write("\x0023\x005")
        b.close()
        self.assertEqual(b.buffer().size(), 5)

if __name__ == '__main__':
    unittest.main()



import sys
import unittest
from helper import adjust_filename
from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtDeclarative import *

class MyClass (QObject):

    def __init__(self):
        super(MyClass,self).__init__()
        self.__url = QUrl()

    def getUrl(self):
        return self.__url

    def setUrl(self,value):
        newUrl = QUrl(value)
        if (newUrl != self.__url):
            self.__url = newUrl
            self.urlChanged.emit()

    urlChanged = Signal()
    urla = Property(QUrl, getUrl, setUrl, notify = urlChanged)

class TestBug926 (unittest.TestCase):
    def testIt(self):
        app = QApplication([])
        qmlRegisterType(MyClass,'Example',1,0,'MyClass')
        view = QDeclarativeView()
        view.setSource(QUrl.fromLocalFile(adjust_filename('bug_926.qml', __file__)))
        self.assertEqual(len(view.errors()), 0)
        view.show()
        QTimer.singleShot(0, app.quit)
        app.exec_()

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import QObject, Property, QCoreApplication
from PySide.QtScript import  QScriptEngine

class MyObject(QObject):
    def __init__(self, parent = None):
        QObject.__init__(self, parent)
        self._p = 100

    def setX(self, value):
        self._p = value

    def getX(self):
        return self._p

    def resetX(self):
        self._p = 100

    def delX(self):
        self._p = 0

    x = Property(int, getX, setX, resetX, delX)


class QPropertyTest(unittest.TestCase):

    def testSimple(self):
        o = MyObject()
        self.assertEqual(o.x, 100)
        o.x = 42
        self.assertEqual(o.x, 42)

    def testHasProperty(self):
        o = MyObject()
        o.setProperty("x", 10)
        self.assertEqual(o.x, 10)
        self.assertEqual(o.property("x"), 10)

    def testMetaProperty(self):
        o = MyObject()
        m = o.metaObject()
        found = False
        for i in range(m.propertyCount()):
            mp = m.property(i)
            if mp.name() == "x":
                found = True
                break
        self.assert_(found)

    def testScriptQProperty(self):
        qapp = QCoreApplication([])
        myEngine = QScriptEngine()
        obj = MyObject()
        scriptObj = myEngine.newQObject(obj)
        myEngine.globalObject().setProperty("obj", scriptObj)
        myEngine.evaluate("obj.x = 42")
        self.assertEqual(scriptObj.property("x").toInt32(), 42)
        self.assertEqual(obj.property("x"), 42)

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import *
from PySide.QtScript import *

class QScriptValueTest(unittest.TestCase):
    def testQScriptValue(self): 
        app = QCoreApplication([])
        engine = QScriptEngine()
        repr(engine.evaluate('1 + 1'))

if __name__ == '__main__':
    unittest.main()



import unittest
import sys

from PySide.QtCore import QObject, QCoreApplication, QEvent, QThread

class MyEvent(QEvent):
    def __init__(self,i):
        print("TYPE:", type(QEvent.User))
        super(MyEvent,self).__init__(QEvent.Type(QEvent.User + 100 ))
        self.i = i

class MyThread (QThread):
    def __init__(self,owner):
        super(MyThread,self).__init__()
        self.owner=owner;

    def run(self):
        for i in range(3):
            e=MyEvent(i);
            QCoreApplication.postEvent(self.owner,e)

class MyBaseObject(QObject):
    def __init__(self):
        QObject.__init__(self)
        self.events = []
        self.t = MyThread(self)
        self.t.start()

    def customEvent(self, event):
        self.events.append(event)
        if len(self.events) == 3:
            self.t.wait()
            self.app.quit()


class CheckForEventsTypes(unittest.TestCase):
    def testTypes(self):
        o = MyBaseObject()
        o.app = QCoreApplication(sys.argv)
        o.app.exec_()
        for e in o.events:
            self.assertTrue(isinstance(e, MyEvent))
        o.app = None

if __name__ == '__main__':
    unittest.main()



''' Test bug 338: http://bugs.openbossa.org/show_bug.cgi?id=338'''

import sys
import unittest
from PySide import QtCore,QtGui

class DiagramItem(QtGui.QGraphicsPolygonItem):
    def __init__(self, parent=None, scene=None):
        super(DiagramItem, self).__init__(parent, scene)

    def itemChange(self, change, value):
        return value


class BugTest(unittest.TestCase):
    def test(self):
        app = QtGui.QApplication(sys.argv)
        scene = QtGui.QGraphicsScene()
        item = DiagramItem()
        item2 = DiagramItem()
        #this cause segfault 
        scene.addItem(item)
        scene.addItem(item2)
  




'''Test cases for QToolbar'''

import unittest

from PySide.QtGui import QToolBar, QMainWindow, QAction

from helper import UsesQApplication

class AddActionText(UsesQApplication):
    '''Test case for calling QToolbar.addAction passing a text'''

    def setUp(self):
        #Acquire resources
        super(AddActionText, self).setUp()
        self.window = QMainWindow()
        self.toolbar = QToolBar()
        self.window.addToolBar(self.toolbar)

    def tearDown(self):
        #Release resources
        super(AddActionText, self).tearDown()
        del self.toolbar
        del self.window

    def testText(self):
        #QToolBar.addAction(text) - add a QToolButton
        self.toolbar.addAction('aaaa')
        self.assertEqual(len(self.toolbar.actions()), 1)
        action = self.toolbar.actions()[0]
        self.assert_(isinstance(action, QAction))
        self.assertEqual(action.text(), 'aaaa')

if __name__ == '__main__':
    unittest.main()




'''Basic test cases for QGraphicsScene'''

import unittest
import gc

from PySide.QtCore import QPointF
from PySide.QtGui import QApplication, QPushButton, QPolygonF, QPixmap
from PySide.QtGui import QGraphicsScene, QPainterPath
from PySide.QtGui import QGraphicsEllipseItem, QGraphicsLineItem
from PySide.QtGui import QGraphicsPathItem, QGraphicsPixmapItem
from PySide.QtGui import QGraphicsPolygonItem, QGraphicsRectItem
from PySide.QtGui import QGraphicsSimpleTextItem, QGraphicsTextItem
from PySide.QtGui import QGraphicsProxyWidget

from helper import UsesQApplication

class Constructor(unittest.TestCase):
    '''QGraphicsScene constructor'''

    def testConstructor(self):
        #QGraphicsScene constructor
        obj = QGraphicsScene()
        self.assertTrue(isinstance(obj, QGraphicsScene))


class ConstructorWithRect(unittest.TestCase):
    '''QGraphicsScene qrect constructor and related sizes'''

    def setUp(self):
        #Acquire resources
        # PyQt4 doesn't accept a QRect as argument to constructor
        self.scene = QGraphicsScene(0, 200, 150, 175)

    def tearDown(self):
        #Release resources
        del self.scene

    def testHeight(self):
        #QGraphicsScene.height()
        self.assertEqual(self.scene.height(), 175)

    def testWidth(self):
        #QGraphicsScene.width()
        self.assertEqual(self.scene.width(), 150)


class AddItem(UsesQApplication):
    '''Tests for QGraphicsScene.add*'''

    qapplication = True

    def setUp(self):
        #Acquire resources
        super(AddItem, self).setUp()
        self.scene = QGraphicsScene()
        # While the scene does not inherits from QWidget, requires
        # an application to make the internals work.

    def tearDown(self):
        #Release resources
        del self.scene
        super(AddItem, self).tearDown()

    def testEllipse(self):
        #QGraphicsScene.addEllipse
        item = self.scene.addEllipse(100, 100, 100, 100)
        self.assertTrue(isinstance(item, QGraphicsEllipseItem))

    def testLine(self):
        #QGraphicsScene.addLine
        item = self.scene.addLine(100, 100, 200, 200)
        self.assertTrue(isinstance(item, QGraphicsLineItem))

    def testPath(self):
        #QGraphicsScene.addPath
        item = self.scene.addPath(QPainterPath())
        self.assertTrue(isinstance(item, QGraphicsPathItem))

    def testPixmap(self):
        #QGraphicsScene.addPixmap
        item = self.scene.addPixmap(QPixmap())
        self.assertTrue(isinstance(item, QGraphicsPixmapItem))

    def testPolygon(self):
        #QGraphicsScene.addPolygon
        points = [QPointF(0, 0), QPointF(100, 100), QPointF(0, 100)]
        item = self.scene.addPolygon(QPolygonF(points))
        self.assertTrue(isinstance(item, QGraphicsPolygonItem))

    def testRect(self):
        #QGraphicsScene.addRect
        item = self.scene.addRect(100, 100, 100, 100)
        self.assertTrue(isinstance(item, QGraphicsRectItem))

    def testSimpleText(self):
        #QGraphicsScene.addSimpleText
        item = self.scene.addSimpleText('Monty Python 42')
        self.assertTrue(isinstance(item, QGraphicsSimpleTextItem))

    def testText(self):
        #QGraphicsScene.addText
        item = self.scene.addText('Monty Python 42')
        self.assertTrue(isinstance(item, QGraphicsTextItem))

    def testWidget(self):
        #QGraphicsScene.addWidget
        # XXX: printing some X11 error when using under PyQt4
        item = self.scene.addWidget(QPushButton())
        self.assertTrue(isinstance(item, QGraphicsProxyWidget))


class ItemRetrieve(UsesQApplication):
    '''Tests for QGraphicsScene item retrieval methods'''

    qapplication = True

    def setUp(self):
        #Acquire resources
        super(ItemRetrieve, self).setUp()
        self.scene = QGraphicsScene()

        self.topleft = QGraphicsRectItem(0, 0, 100, 100)
        self.topright = QGraphicsRectItem(100, 0, 100, 100)
        self.bottomleft = QGraphicsRectItem(0, 100, 100, 100)
        self.bottomright = QGraphicsRectItem(100, 100, 100, 100)

        self.items = [self.topleft, self.topright, self.bottomleft,
                        self.bottomright]

        for item in self.items:
            self.scene.addItem(item)

    def tearDown(self):
        #Release resources
        del self.scene
        super(ItemRetrieve, self).tearDown()

    def testItems(self):
        #QGraphicsScene.items()
        items = self.scene.items()
        for i in items:
            self.assertTrue(i in self.items)

    def testItemAt(self):
        #QGraphicsScene.itemAt()
        self.assertEqual(self.scene.itemAt(50, 50), self.topleft)
        self.assertEqual(self.scene.itemAt(150, 50), self.topright)
        self.assertEqual(self.scene.itemAt(50, 150), self.bottomleft)
        self.assertEqual(self.scene.itemAt(150, 150), self.bottomright)

class TestGraphicsGroup(UsesQApplication):
    def testIt(self):
        scene = QGraphicsScene()
        i1 = QGraphicsRectItem()
        scene.addItem(i1)
        i2 = QGraphicsRectItem(i1)
        i3 = QGraphicsRectItem()
        i4 = QGraphicsRectItem()
        group = scene.createItemGroup((i2, i3, i4))
        scene.removeItem(i1)
        del i1 # this shouldn't delete i2
        self.assertEqual(i2.scene(), scene)
        scene.destroyItemGroup(group)
        self.assertRaises(RuntimeError, group.type)


if __name__ == '__main__':
    unittest.main()



import unittest
import py3kcompat as py3k
from helper import UsesQApplication
from PySide.QtCore import QSize
from PySide.QtGui import QBitmap, QImage

class TestQBitmap(UsesQApplication):
    def testFromDataMethod(self):
        dataBits = py3k.b('\x38\x28\x38\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\x10\xfe\xfe\x7c\x7c\x38\x38\x10\x10')
        bim = QBitmap.fromData(QSize(8, 48), dataBits, QImage.Format_Mono) # missing function

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Producer-Consumer test/example with QThread'''

import unittest
from random import random
import logging

logging.basicConfig(level=logging.WARNING)

from PySide.QtCore import QThread, QCoreApplication, QObject, SIGNAL

class Bucket(QObject):
    '''Dummy class to hold the produced values'''
    def __init__(self, max_size=10, *args):
        #Constructor which receives the max number of produced items
        super(Bucket, self).__init__(*args)
        self.data = []
        self.max_size = 10

    def pop(self):
        #Retrieves an item
        return self.data.pop(0)

    def push(self, data):
        #Pushes an item
        self.data.append(data)

class Producer(QThread):
    '''Producer thread'''

    def __init__(self, bucket, *args):
        #Constructor. Receives the bucket
        super(Producer, self).__init__(*args)
        self.runs = 0
        self.bucket = bucket
        self.production_list = []

    def run(self):
        #Produces at most bucket.max_size items
        while self.runs < self.bucket.max_size:
            value = int(random()*10) % 10
            self.bucket.push(value)
            self.production_list.append(value)
            logging.debug('PRODUCER - pushed %d' % value)
            self.runs += 1
            self.msleep(5)



class Consumer(QThread):
    '''Consumer thread'''
    def __init__(self, bucket, *args):
        #Constructor. Receives the bucket
        super(Consumer, self).__init__(*args)
        self.runs = 0
        self.bucket = bucket
        self.consumption_list = []

    def run(self):
        #Consumes at most bucket.max_size items
        while self.runs < self.bucket.max_size:
            try:
                value = self.bucket.pop()
                self.consumption_list.append(value)
                logging.debug('CONSUMER - got %d' % value)
                self.runs += 1
            except IndexError:
                logging.debug('CONSUMER - empty bucket')
            self.msleep(5)

class ProducerConsumer(unittest.TestCase):
    '''Basic test case for producer-consumer QThread'''

    def setUp(self):
        #Create fixtures
        self.app = QCoreApplication([])

    def tearDown(self):
        #Destroy fixtures
        del self.app

    def finishCb(self):
        #Quits the application
        self.app.exit(0)

    def testProdCon(self):
        #QThread producer-consumer example
        bucket = Bucket()
        prod = Producer(bucket)
        cons = Consumer(bucket)

        prod.start()
        cons.start()

        QObject.connect(prod, SIGNAL('finished()'), self.finishCb)
        QObject.connect(cons, SIGNAL('finished()'), self.finishCb)

        self.app.exec_()

        prod.wait()
        cons.wait()

        self.assertEqual(prod.production_list, cons.consumption_list)


if __name__ == '__main__':
    unittest.main()



""" Unittest for bug #547 """
""" http://bugs.openbossa.org/show_bug.cgi?id=547 """

from PySide import QtGui
import sys
import unittest

class MyMainWindow(unittest.TestCase):
    app = QtGui.QApplication(sys.argv)
    def testCase1(self):
        self._tree = QtGui.QTreeWidget()
        self._tree.setColumnCount(2)
        self._i1 = None
        self._i11 = None

        self._updateTree()
        self.assertEqual(sys.getrefcount(self._i1), 3)
        self.assertEqual(sys.getrefcount(self._i11), 3)

        self._i11.parent().setExpanded(True)
        self._i11.setExpanded(True)

        self._updateTree()
        self.assertEqual(sys.getrefcount(self._i1), 3)
        self.assertEqual(sys.getrefcount(self._i11), 3)

    def testCase2(self):
        self._tree = QtGui.QTreeWidget()
        self._tree.setColumnCount(2)
        self._i1 = None
        self._i11 = None

        self._updateTree()
        self.assertEqual(sys.getrefcount(self._i1), 3)
        self.assertEqual(sys.getrefcount(self._i11), 3)

        self._i11.parent().setExpanded(True)
        self._i11.setExpanded(True)

        self.assertEqual(sys.getrefcount(self._i1), 3)
        self.assertEqual(sys.getrefcount(self._i11), 3)

    def _updateTree(self):
        self._tree.clear()
        if self._i1 and self._i11:
            self.assertEqual(sys.getrefcount(self._i1), 2)
            self.assertEqual(sys.getrefcount(self._i11), 2)

        self._i1 = QtGui.QTreeWidgetItem(self._tree, ['1', ])
        self.assertEqual(sys.getrefcount(self._i1), 3)
        self._i11 = QtGui.QTreeWidgetItem(self._i1, ['11', ])
        self.assertEqual(sys.getrefcount(self._i11), 3)

if __name__ == '__main__':
    unittest.main()




import os
import sys
import shutil
import unittest
import py3kcompat as py3k

orig_path = os.path.join(os.path.dirname(__file__))
workdir = os.getcwd()
src = os.path.join(orig_path, 'test_module_template.py')
dst = os.path.join(workdir, 'test_module.py')
shutil.copyfile(src, dst)
sys.path.append(workdir)

def reload_module(moduleName):
    if py3k.IS_PY3K:
        import imp
        imp.reload(moduleName)
    else:
        reload(moduleName)

def increment_module_value():
    modfile = open(dst, 'a')
    modfile.write('Sentinel.value += 1' + os.linesep)
    modfile.flush()
    modfile.close()
    if not sys.dont_write_bytecode:
        if py3k.IS_PY3K:
            import imp
            cacheFile = imp.cache_from_source(dst)
        else:
            cacheFile = dst + 'c'
        os.remove(cacheFile)

class TestModuleReloading(unittest.TestCase):

    def testModuleReloading(self):
        '''Test module reloading with on-the-fly modifications.'''

        import test_module
        self.assertEqual(test_module.Sentinel.value, 10)

        increment_module_value()
        reload_module(sys.modules['test_module'])
        self.assertEqual(test_module.Sentinel.value, 11)

        reload_module(sys.modules['test_module'])
        self.assertEqual(test_module.Sentinel.value, 11)

        increment_module_value()
        reload_module(sys.modules['test_module'])
        self.assertEqual(test_module.Sentinel.value, 12)

if __name__ == "__main__":
    unittest.main()





from testbinding import *
import unittest

class TestBug1016 (unittest.TestCase):

    def testIt(self):
        obj = getHiddenObject()
        self.assertEqual(obj.callMe(), None)
        self.assertTrue(obj.wasCalled())

if __name__ == "__main__":
    unittest.main()



import unittest

from PySide.QtCore import QByteArray
from helper.docmodifier import DocModifier

class BaseQByteArrayOperatorIAdd(object):
    '''Base class for QByteArray += operator tests.

    Implementing classes should inherit from unittest.TestCase and implement
    setUp, setting self.obj and self.orig_obj to the target QByteArray and original
    one, respectively'''

    __metaclass__ = DocModifier

    def testSingleString(self):
        '''QByteArray += string of size 1'''
        s = '0'
        self.obj += s
        self.assertEqual(self.obj, self.orig_obj + s)
        self.assertEqual(self.obj.size(), self.orig_obj.size() + len(s))

    def testString(self):
        '''QByteArray += string of size > 1'''
        s = 'dummy'
        self.obj += s
        self.assertEqual(self.obj, self.orig_obj + s)
        self.assertEqual(self.obj.size(), self.orig_obj.size() + len(s))

    def testQByteArray(self):
        '''QByteArray += QByteArray'''
        s = QByteArray('array')
        self.obj += s
        self.assertEqual(self.obj, self.orig_obj + s)

    def testChar(self):
        '''QByteArray += char (number < 256)'''
        s = ord('a')
        self.obj += s
        self.assertEqual(self.obj, self.orig_obj + s)
        self.assertEqual(self.obj.size(), self.orig_obj.size() + 1)

class NullQByteArrayOperatorIAdd(unittest.TestCase, BaseQByteArrayOperatorIAdd):
    '''Test case for operator QByteArray += on null QByteArrays'''

    doc_prefix = 'Null object'
    doc_filter = lambda x: x.startswith('test')

    def setUp(self):
        self.obj = QByteArray()
        self.orig_obj = QByteArray()


class ValidQByteArrayOperatorIAdd(unittest.TestCase, BaseQByteArrayOperatorIAdd):
    '''Test case for operator QByteArray += on valid QByteArrays'''

    doc_prefix = 'Valid object'
    doc_filter = lambda x: x.startswith('test')

    def setUp(self):
        self.obj = QByteArray('some byte array')
        self.orig_obj = QByteArray('some byte array')

if __name__ == '__main__':
    unittest.main()



'''Test cases for PySide API2 support'''


import unittest
import sys

from PySide.QtGui import QWidget, QIntValidator, QSpinBox, QValidator, QApplication

from helper import UsesQApplication

class WidgetValidatorQInt(QWidget, QIntValidator):
    def __init__(self, parent=None):
        QWidget.__init__(self, parent)
        QIntValidator.__init__(self, parent)

class WidgetValidatorQSpinBox(QSpinBox):
    def __init__(self, parent=None):
        QSpinBox.__init__(self, parent)

    def fixup(self, text):
        print("It was called!")

class DoubleQObjectInheritanceTest(UsesQApplication):

    def testDouble(self):
        '''Double inheritance from QObject classes'''

        obj = WidgetValidatorQInt()

        #QIntValidator methods
        state, string, number = obj.validate('Test', 0)
        self.assertEqual(state, QValidator.Invalid)
        state, string, number = obj.validate('33', 0)
        self.assertEqual(state, QValidator.Acceptable)

    def testQSpinBox(self):
        obj = WidgetValidatorQSpinBox()

        obj.setRange(1, 10)
        obj.setValue(0)
        self.assertEqual(obj.value(), 1)

class QClipboardTest(UsesQApplication):

    def testQClipboard(self):
        #skip this test on MacOS because the clipboard is not available during the ssh session
        #this cause problems in the buildbot
        if sys.platform == 'darwin':
            return
        clip = QApplication.clipboard()
        clip.setText("Testing this thing!")

        text, subtype = clip.text("")
        self.assertEqual(subtype, "plain")
        self.assertEqual(text, "Testing this thing!")

if __name__ == '__main__':
    unittest.main()



""" Unittest for bug #515 """
""" http://bugs.openbossa.org/show_bug.cgi?id=515 """

from PySide import QtCore

callCleanup = False
def _cleanup():
    global callCleanup
    callCleanup = True

def _checkCleanup():
    global callCleanup
    assert(callCleanup)

app = QtCore.QCoreApplication([])
QtCore.qAddPostRoutine(_cleanup)
QtCore.qAddPostRoutine(_checkCleanup)
del app




'Tests for processtimer.py'

import unittest
import os

from subprocess import Popen, PIPE
from processtimer import TimeoutException, ProcessTimer

class TimeoutTest(unittest.TestCase):

    def tearDown(self):
        try:
            os.kill(self.proc.pid, 9)
        except OSError:
            pass

    def testRaise(self):
        self.proc = Popen(['python2.5', '-c', 'while True: pass' ], stdout=PIPE, stderr=PIPE)
        timer = ProcessTimer(self.proc, 1)
        self.assertRaises(TimeoutException, timer.waitfor)

class SimpleTest(unittest.TestCase):

    def tearDown(self):
        try:
            os.kill(self.proc.pid, 9)
        except OSError:
            pass
    def testSimple(self):
        self.proc = Popen(['python2.5', '-c', '"print"'], stdout=PIPE, stderr=PIPE)
        timer = ProcessTimer(self.proc, 10)
        timer.waitfor()

class TestEchoOutput(unittest.TestCase):

    def tearDown(self):
        try:
            os.kill(self.proc.pid, 9)
        except OSError:
            pass

    def testOutput(self):
        self.proc = Popen(['python2.5', '-c', 'print 1',], stdout=PIPE, stderr=PIPE)
        timer = ProcessTimer(self.proc, 1)
        timer.waitfor()
        self.assertEqual(self.proc.stdout.read().strip(), '1')

class TestRetCode(unittest.TestCase):

    def tearDown(self):
        try:
            os.kill(self.proc.pid, 9)
        except OSError:
            pass

    def testSimple(self):
        self.proc = Popen(['python2.5', '-c', 'print 1'], stdout=PIPE, stderr=PIPE)
        timer = ProcessTimer(self.proc, 10)
        timer.waitfor()

        self.assertEqual(self.proc.poll(), 0)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

'''Test case for duck punching new implementations of C++ virtual methods into object instances.'''

import unittest
import types
import sys
from PySide.QtCore import QObject
from helper import UsesQCoreApplication

def MethodType(func, instance, instanceType):
    if sys.version_info[0] == 3:
        return types.MethodType(func, instance)
    else:
        return types.MethodType(func, instance, instanceType)

class Duck(QObject):
    def __init__(self):
        QObject.__init__(self)
    def childEvent(self, event):
        QObject.childEvent(self, event)

class TestDuckPunchingOnQObjectInstance(UsesQCoreApplication):
    '''Test case for duck punching new implementations of C++ virtual methods into object instances.'''

    def setUp(self):
        #Acquire resources
        self.duck_childEvent_called = False
        UsesQCoreApplication.setUp(self)

    def tearDown(self):
        #Release resources
        del self.duck_childEvent_called
        UsesQCoreApplication.tearDown(self)


    def testChildEventMonkeyPatch(self):
        #Test if the new childEvent injected on QObject instance is called from C++
        parent = QObject()
        def childEvent(obj, event):
            self.duck_childEvent_called = True
        parent.childEvent = MethodType(childEvent, parent, QObject)
        child = QObject()
        child.setParent(parent)
        self.assert_(self.duck_childEvent_called)
        # This is done to decrease the refcount of the vm object
        # allowing the object wrapper to be deleted before the
        # BindingManager. This is useful when compiling Shiboken
        # for debug, since the BindingManager destructor has an
        # assert that checks if the wrapper mapper is empty.
        parent.childEvent = None

    def testChildEventMonkeyPatchWithInheritance(self):
        #Test if the new childEvent injected on a QObject's extension class instance is called from C++
        parent = Duck()
        def childEvent(obj, event):
            QObject.childEvent(obj, event)
            self.duck_childEvent_called = True
        child = QObject()
        child.setParent(parent)
        parent.childEvent = MethodType(childEvent, parent, QObject)
        child = QObject()
        child.setParent(parent)
        self.assert_(self.duck_childEvent_called)
        # This is done to decrease the refcount of the vm object
        # allowing the object wrapper to be deleted before the
        # BindingManager. This is useful when compiling Shiboken
        # for debug, since the BindingManager destructor has an
        # assert that checks if the wrapper mapper is empty.
        parent.childEvent = None

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtGui import *
from PySide.phonon import *


class TestBug786 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])
        app.setApplicationName("PySide Phonon Unit Test")
        devices = Phonon.BackendCapabilities.availableAudioOutputDevices()
        if len(devices) > 1:
            if devices[0].index() != devices[0].index():
                self.assertNotEqual(devices[0], devices[1])
            self.assertEqual(devices[0], devices[0])

        effects = Phonon.BackendCapabilities.availableAudioEffects()
        if len(effects) > 1:
            self.assertNotEqual(effects[0], effects[1])
            self.assertEqual(effects[0], effects[0])

if __name__ == '__main__':
    unittest.main()



import unittest
import pickle
from PySide.QtGui import QColor

class TestQColor (unittest.TestCase):
    def reduceColor(self, c):
        p = pickle.dumps(c)
        c2 = pickle.loads(p)
        self.assertEqual(c.spec(), c2.spec())
        self.assertEqual(c, c2)

    def testReduceEmpty(self):
        self.reduceColor(QColor())

    def testReduceString(self):
        self.reduceColor(QColor('gray'))

    def testReduceRGB(self):
        self.reduceColor(QColor.fromRgbF(0.1, 0.2, 0.3, 0.4))

    def testReduceCMYK(self):
        self.reduceColor(QColor.fromCmykF(0.1, 0.2, 0.3, 0.4, 0.5))

    def testReduceHsl(self):
        self.reduceColor(QColor.fromHslF(0.1, 0.2, 0.3, 0.4))

    def testReduceHsv(self):
        self.reduceColor(QColor.fromHsvF(0.1, 0.2, 0.3, 0.4))

if __name__ == "__main__":
    unittest.main()




import unittest
from PySide.QtCore import *
from PySide.QtGui import *

class QPolygonFNotIterableTest(unittest.TestCase):
    """Test if a QPolygonF is iterable"""
    def testIt(self):
        p = QPolygonF(4)
        self.assertEqual(len(p), 4)

        for i in range(0, 4):
            p[i] = QPointF(float(i), float(i))

        i = 0
        for point in p:
            self.assertEqual(int(point.x()), i)
            self.assertEqual(int(point.y()), i)
            i += 1;

    def testPolygonShiftOperators(self):
        p = QPolygon()
        self.assertEqual(len(p), 0)
        p << QPoint(10, 20) << QPoint(20, 30) << [QPoint(20, 30), QPoint(40, 50)]
        self.assertEqual(len(p), 4)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import unittest
from PySide import __version_info__, __version__, QtCore

class CheckForVariablesTest(unittest.TestCase):
    def testVesions(self):
        self.assert_(__version_info__ >= (1, 0, 0))
        self.assert_(__version_info__ < (99, 99, 99))
        self.assert_(__version__)

        self.assert_(QtCore.__version_info__ >= (4, 5, 0))
        self.assert_(QtCore.__version__)

if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-
import unittest
from PySide.QtCore import *


class SignalPrimitiveTypeTest(unittest.TestCase):

    def signalValueChanged(self, v):
        self.called = True
        self._app.quit()

    def createTimeLine(self):
        self.called = False
        tl = QTimeLine(10000)
        QObject.connect(tl, SIGNAL("valueChanged(qreal)"), self.signalValueChanged)
        return tl

    def testTimeLine(self):
        self._valueChangedCount = 0
        self._app = QCoreApplication([])
        tl = self.createTimeLine()
        tl.start()
        self._app.exec_()
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()






import unittest

from PySide.QtCore import Qt
from PySide.QtGui import QPushButton
from helper import UsesQApplication

class QInputContextTest(UsesQApplication):

    def testSetFocusWidget(self):
        widget = QPushButton()
        widget.show()

        context = self.app.inputContext()
        self.assertEqual(context.focusWidget(), None)

        if not widget.testAttribute(Qt.WA_InputMethodEnabled):
            widget.setAttribute(Qt.WA_InputMethodEnabled)

        context.setFocusWidget(widget)
        self.assertEqual(context.focusWidget(), widget)


if __name__ == '__main__':
    unittest.main()





from PySide.QtCore import QObject
from PySide.QtGui import *
import PySide.QtCore
import unittest

class MyQObject(QObject):
    def __init__(self):
        QObject.__init__(self)

class MyQWidget(QWidget):
    def __init__(self):
        QWidget.__init__(self)

class MyQGraphicsObject(QGraphicsObject):
    def __init__(self):
        QGraphicsObject.__init__(self)

class MyQGraphicsItem(QGraphicsItem):
    def __init__(self):
        QGraphicsItem.__init__(self)

class TestRepr (unittest.TestCase):

    def testIt(self):

        app = QApplication([])

        self.assertEqual("<__main__.MyQObject object at ", repr(MyQObject())[:30])
        self.assertEqual("<__main__.MyQWidget object at ", repr(MyQWidget())[:30])
        self.assertEqual("<__main__.MyQGraphicsObject(this = 0x", repr(MyQGraphicsObject())[:37])
        self.assertEqual("<__main__.MyQGraphicsItem(this = 0x", repr(MyQGraphicsItem())[:35])

        self.assertEqual("<PySide.QtCore.QObject object at ", repr(QObject())[:33])
        self.assertEqual("<PySide.QtCore.QObject object at ", repr(PySide.QtCore.QObject())[:33])
        self.assertEqual("<PySide.QtGui.QWidget object at ", repr(QWidget())[:32])
        self.assertEqual("<PySide.QtGui.QGraphicsWidget(this = 0x", repr(QGraphicsWidget())[:39])

if __name__ == "__main__":
    unittest.main()



'''Test cases for QIPv6Address'''

import unittest

from PySide.QtNetwork import *

class QIPv6AddressGetItemTest(unittest.TestCase):
    def testLength(self):
        ip = QIPv6Address()
        self.assertEqual(len(ip), 16)

    def testSetItemNegativeIndex(self):
        ip = QIPv6Address()
        ip[-1] = 8
        self.assertEqual(ip[-1], 8)

    def testSetItemLargeIndex(self):
        ip = QIPv6Address()
        self.assertRaises(IndexError, ip.__setitem__, 32, 16)

if __name__ == '__main__':
    unittest.main()



import unittest

from helper import UsesQApplication
from PySide.QtGui import QPushButton, QMenu, QWidget
from PySide.QtCore import QTimer

class MyWidget(QWidget):
    def __init__(self):
        QWidget.__init__(self)

        m = QMenu(self)
        b = QPushButton("Hello", self)
        b.setMenu(m)


class QPushButtonTest(UsesQApplication):
    def createMenu(self, button):
        m = QMenu()
        button.setMenu(m)

    def testSetMenu(self):
        w = MyWidget()
        w.show()

        timer = QTimer.singleShot(100, self.app.quit)
        self.app.exec_()

    def buttonCb(self, checked):
        self._clicked = True

    def testBoolinSignal(self):
        b = QPushButton()
        b.setCheckable(True)
        self._clicked = False
        b.toggled[bool].connect(self.buttonCb)
        b.toggle()
        self.assert_(self._clicked)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
'''Test cases for QLineF'''

import unittest
import datetime

from PySide.QtCore import QTime, QDateTime, QDate

class TestDateTimeConversions (unittest.TestCase):
    def testQDate(self):
        date = datetime.date(2010, 4, 23)
        other = QDate(date)
        self.assertEqual(date.year, other.year())
        self.assertEqual(date.month, other.month())
        self.assertEqual(date.day, other.day())

        self.assertEqual(date, other.toPython())

    def testQTime(self):
        time = datetime.time(11, 14, 0, 1000)
        other = QTime(time)
        self.assertEqual(time.hour, other.hour())
        self.assertEqual(time.minute, other.minute())
        self.assertEqual(time.second, other.second())
        self.assertEqual(time.microsecond/1000, other.msec())

        self.assertEqual(time, other.toPython())

    def testQDateTime(self):
        dateTime = datetime.datetime(2010, 4, 23, 11, 14, 0, 1000)
        other = QDateTime(dateTime)

        otherDate = other.date()
        self.assertEqual(dateTime.year, otherDate.year())
        self.assertEqual(dateTime.month, otherDate.month())
        self.assertEqual(dateTime.day, otherDate.day())

        otherTime = other.time()
        self.assertEqual(dateTime.hour, otherTime.hour())
        self.assertEqual(dateTime.minute, otherTime.minute())
        self.assertEqual(dateTime.second, otherTime.second())
        self.assertEqual(dateTime.microsecond/1000, otherTime.msec())

        self.assertEqual(dateTime, other.toPython())

    def testQDateTime6arg(self):
        dateTime = datetime.datetime(2010, 4, 23, 11, 14, 7)
        other = QDateTime(dateTime)

        otherDate = other.date()
        self.assertEqual(dateTime.year, otherDate.year())
        self.assertEqual(dateTime.month, otherDate.month())
        self.assertEqual(dateTime.day, otherDate.day())

        otherTime = other.time()
        self.assertEqual(dateTime.hour, otherTime.hour())
        self.assertEqual(dateTime.minute, otherTime.minute())
        self.assertEqual(dateTime.second, otherTime.second())
        self.assertEqual(dateTime.microsecond/1000, otherTime.msec())

        self.assertEqual(dateTime, other.toPython())

if __name__ == '__main__':
    unittest.main()



from   PySide.QtCore import *
from   PySide.QtGui  import *

class Ball(QGraphicsEllipseItem):
    def __init__(self, d, parent=None):
        super(Ball, self).__init__(0, 0, d, d, parent)
        self.vel = QPointF(0,0)   #commenting this out prevents the crash

class Foo(QGraphicsView):
    def __init__(self):
        super(Foo, self).__init__(None)
        self.scene = QGraphicsScene(self.rect())
        self.setScene(self.scene)
        self.scene.addItem(Ball(10))


if __name__ == "__main__":
    import sys
    app = QApplication(sys.argv)
    w = Foo()
    w.show()
    w.raise_()
    QTimer.singleShot(0, w.close)
    sys.exit(app.exec_())



import unittest

import PySide
from PySide.QtCore import QPoint, QPointF
from PySide.QtCore import QLine, QLineF
from PySide.QtCore import QSize, QSizeF

class testCases(unittest.TestCase):
    def testQPointToTuple(self):
        p = QPoint(1, 2)
        self.assertEqual((1, 2), p.toTuple())

    def testQPointFToTuple(self):
        p = QPointF(1, 2)
        self.assertEqual((1, 2), p.toTuple())

    def testQLineToTuple(self):
        l = QLine(1, 2, 3, 4)
        self.assertEqual((1, 2, 3, 4), l.toTuple())

    def testQLineFToTuple(self):
        l = QLineF(1, 2, 3, 4)
        self.assertEqual((1, 2, 3, 4), l.toTuple())

    def testQSizeToTuple(self):
        s = QSize(1, 2)
        self.assertEqual((1, 2), s.toTuple())

    def testQSizeFToTuple(self):
        s = QSizeF(1, 2)
        self.assertEqual((1, 2), s.toTuple())

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from PySide.QtCore import *


class QStateTest(unittest.TestCase):
    def testBasic(self):
        app = QCoreApplication([])

        o = QObject()
        o.setProperty("text", "INdT")

        machine = QStateMachine()
        s1 = QState()
        s1.assignProperty(o, "text", "Rocks");

        s2 = QFinalState()
        t = s1.addTransition(o, SIGNAL("change()"), s2);
        self.assert_(isinstance(t, QSignalTransition))

        machine.addState(s1)
        machine.addState(s2)
        machine.setInitialState(s1)
        machine.start()

        o.emit(SIGNAL("change()"))

        QTimer.singleShot(100, app.quit)
        app.exec_()

        txt = o.property("text")
        self.assert_(txt, "Rocks")

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtGui import QMenu, QKeySequence, QIcon
from PySide.QtCore import SLOT

from helper import UsesQApplication

class QMenuAddAction(UsesQApplication):

    def setUp(self):
        super(QMenuAddAction, self).setUp()
        self.menu = QMenu()

    def tearDown(self):
        del self.menu
        super(QMenuAddAction, self).tearDown()

    def testAddActionWithoutKeySequenceCallable(self):
        # bug #280
        action = self.menu.addAction(self.app.tr('aaa'), lambda : 1)

    def testAddActionKeySequenceCallable(self):
        # bug #228
        action = self.menu.addAction(self.app.tr('aaa'), lambda : 1,
                                    QKeySequence(self.app.tr('Ctrl+O')))

    def testAddActionKeySequenceSlot(self):
        action = self.menu.addAction('Quit', self.app, SLOT('quit()'),
                                    QKeySequence('Ctrl+O'))

class QMenuAddActionWithIcon(UsesQApplication):

    def setUp(self):
        super(QMenuAddActionWithIcon, self).setUp()
        self.menu = QMenu()
        self.icon = QIcon()

    def tearDown(self):
        del self.menu
        del self.icon
        super(QMenuAddActionWithIcon, self).tearDown()

    def testAddActionWithoutKeySequenceCallable(self):
        # bug #280
        action = self.menu.addAction(self.icon, self.app.tr('aaa'), lambda : 1)

    def testAddActionKeySequenceCallable(self):
        # bug #228
        action = self.menu.addAction(self.icon, self.app.tr('aaa'), lambda : 1,
                                    QKeySequence(self.app.tr('Ctrl+O')))

    def testAddActionKeySequenceSlot(self):
        action = self.menu.addAction(self.icon, 'Quit', self.app, SLOT('quit()'),
                                    QKeySequence('Ctrl+O'))

if __name__ == '__main__':
    unittest.main()



import unittest
import sys
from PySide.QtCore import QObject, ClassInfo

@ClassInfo(author='pyside',url='http://www.pyside.org')
class MyObject(QObject):
    pass

class TestClassInfo(unittest.TestCase):
    def testMetaData(self):
        o = MyObject()
        mo = o.metaObject()
        self.assertEqual(mo.classInfoCount(), 2)

        ci = mo.classInfo(0) #author
        self.assertEqual(ci.name(), 'author')
        self.assertEqual(ci.value(), 'pyside')

        ci = mo.classInfo(1) #url
        self.assertEqual(ci.name(), 'url')
        self.assertEqual(ci.value(), 'http://www.pyside.org')

if __name__ == '__main__':
    if sys.version_info[0] < 2:
        sys.exit(0)
    elif (sys.version_info[0] == 2) and (sys.version_info[1] <= 5):
        sys.exit(0)
    else:
        unittest.main()



#!/usr/bin/python
'''Test cases for QtCore.QEvent'''

import unittest

from PySide.QtCore import QEvent

class QEventTypeFlag(unittest.TestCase):
    '''Test case for usage of QEvent.Type flags'''

    def testFlagAccess(self):
        #QEvent.Type flags usage

        event = QEvent(QEvent.Timer)
        self.assertEqual(event.type(), QEvent.Timer)

        event = QEvent(QEvent.Close)
        self.assertEqual(event.type(), QEvent.Close)

        event = QEvent(QEvent.IconTextChange)
        self.assertEqual(event.type(), QEvent.IconTextChange)

if __name__ == '__main__':
    unittest.main()



'''Test cases for Virtual functions with wrong return type'''

import unittest
import py3kcompat as py3k
from PySide import QtGui
from helper import UsesQApplication

import warnings
warnings.simplefilter('error')


class MyWidget(QtGui.QWidget):
    def __init__(self, parent=None):
        super(MyWidget, self).__init__(parent)

    def sizeHint(self):
        pass

class testCase(UsesQApplication):

    def testVirtualReturn(self):
        w = MyWidget()
        if py3k.IS_PY3K:
            self.assertWarns(RuntimeWarning, w.show)
        else:
            self.assertRaises(RuntimeWarning, w.show)


if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import *
from PySide.QtNetwork import *

from helper import UsesQCoreApplication

class HttpSignalsCase(UsesQCoreApplication):
    '''Test case for launching QHttp signals'''
    DATA = "PySide rocks"

    def onError(self):
        self.assert_(False)

    def onNewConnection(self):
        self.serverConnection = self.server.nextPendingConnection()
        self.serverConnection.error.connect(self.onError)
        self.serverConnection.write(HttpSignalsCase.DATA)
        self.server.close()

    def onReadReady(self):
        data = self.client.read(100)
        self.assertEqual(data.size(), len(HttpSignalsCase.DATA))
        self.assertEqual(data, HttpSignalsCase.DATA)
        self.done()

    def onClientConnect(self):
        self.client.readyRead.connect(self.onReadReady)

    def initServer(self):
        self.server = QTcpServer()
        self.server.newConnection.connect(self.onNewConnection)
        self.assert_(self.server.listen())
        self.client = QTcpSocket()
        self.client.connected.connect(self.onClientConnect)
        self.client.connectToHost(QHostAddress(QHostAddress.LocalHost), self.server.serverPort())

    def done(self):
        self.serverConnection.close()
        self.client.close()
        self.app.quit()

    def testRun(self):
        self.initServer()
        self.app.exec_()

if __name__ == '__main__':
    unittest.main()



from PySide import QtUiTools
from PySide import QtCore
from PySide import QtGui
from helper import adjust_filename

app = QtGui.QApplication([])
loader = QtUiTools.QUiLoader()
file = QtCore.QFile(adjust_filename('bug_552.ui', __file__))
w = QtGui.QWidget()
# An exception can't be thrown
mainWindow = loader.load(file, w)




'''Test cases for QPoint and QPointF'''

import unittest

from PySide.QtCore import QPoint, QPointF


class QPointTest(unittest.TestCase):

    def testQPointCtor(self):
        point = QPoint(QPoint(10,20))

class QPointFTest(unittest.TestCase):

    def testQPointFCtor(self):
        pointf = QPointF(QPoint(10,20))

if __name__ == '__main__':
    unittest.main()





from PySide.QtCore import *
from PySide.QtGui import *
import unittest

class MyModel (QAbstractListModel):

    stupidLine = QLine(0, 0, 10, 10)

    def rowCount(self, parent):
        return 1

    def data(self, index, role):
        return self.stupidLine

class TestBug693(unittest.TestCase):
    def testIt(self):
        app = QApplication([])
        model = MyModel()
        view = QListView()
        view.setModel(model)
        view.show()

        # This must NOT throw the exception:
        # RuntimeError: Internal C++ object (PySide.QtCore.QLine) already deleted.
        MyModel.stupidLine.isNull()



if __name__ == "__main__":
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *

import unittest
from helper import UsesQApplication

class MyValidator1(QValidator):
    def fixUp(self, input):
        return "fixed"

    def validate(self, input, pos):
        return (QValidator.Acceptable, "fixed", 1)

class MyValidator2(QValidator):
    def fixUp(self, input):
        return "fixed"

    def validate(self, input, pos):
        return (QValidator.Acceptable, "fixed")

class MyValidator3(QValidator):
    def fixUp(self, input):
        return "fixed"

    def validate(self, input, pos):
        return (QValidator.Acceptable,)

class MyValidator4(QValidator):
    def fixUp(self, input):
        return "fixed"

    def validate(self, input, pos):
        return QValidator.Acceptable

class QValidatorTest(UsesQApplication):
    def testValidator1(self):
        line = QLineEdit()
        line.setValidator(MyValidator1())
        line.show()
        line.setText("foo")

        QTimer.singleShot(0, line.close)
        self.app.exec_()

        self.assertEqual(line.text(), "fixed")
        self.assertEqual(line.cursorPosition(), 1)

    def testValidator2(self):
        line = QLineEdit()
        line.setValidator(MyValidator2())
        line.show()
        line.setText("foo")

        QTimer.singleShot(0, line.close)
        self.app.exec_()

        self.assertEqual(line.text(), "fixed")
        self.assertEqual(line.cursorPosition(), 3)

    def testValidator3(self):
        line = QLineEdit()
        line.setValidator(MyValidator3())
        line.show()
        line.setText("foo")

        QTimer.singleShot(0, line.close)
        self.app.exec_()

        self.assertEqual(line.text(), "foo")
        self.assertEqual(line.cursorPosition(), 3)

    def testValidator4(self):
        line = QLineEdit()
        line.setValidator(MyValidator4())
        line.show()
        line.setText("foo")

        QTimer.singleShot(0, line.close)
        self.app.exec_()

        self.assertEqual(line.text(), "foo")
        self.assertEqual(line.cursorPosition(), 3)

if __name__ == '__main__':
    unittest.main()




''' Test cases related to QGraphicsItem and subclasses'''

import unittest

from PySide.QtGui import QGraphicsScene, QPolygonF, QColor, QBrush

from helper import UsesQApplication

class QColorOnSetBrush(UsesQApplication):
    '''Test case for passing a QColor directly to setBrush'''

    def setUp(self):
        #Acquire resources
        super(QColorOnSetBrush, self).setUp()

        self.scene = QGraphicsScene()
        poly = QPolygonF()
        self.item = self.scene.addPolygon(poly)
        self.color = QColor('black')

    def tearDown(self):
        #Release resources
        del self.color
        del self.item
        del self.scene
        super(QColorOnSetBrush, self).tearDown()

    def testQColor(self):
        #QGraphicsAbstractShapeItem.setBrush(QColor)
        self.item.setBrush(self.color)
        self.assertEqual(QBrush(self.color), self.item.brush())

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import QObject
from PySide.QtGui import QPen, QBrush

class TestBug991 (unittest.TestCase):
    def testReprFunction(self):
        reprPen = repr(QPen())
        self.assertTrue(reprPen.startswith("<PySide.QtGui.QPen"))
        reprBrush = repr(QBrush())
        self.assertTrue(reprBrush.startswith("<PySide.QtGui.QBrush"))
        reprObject = repr(QObject())
        self.assertTrue(reprObject.startswith("<PySide.QtCore.QObject"))

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import *
from PySide.QtGui import *

class TestBug653(unittest.TestCase):
    """Crash after calling QWizardPage.wizard()"""
    def testIt(self):
        app = QApplication([])

        wizard = QWizard()
        page = QWizardPage()
        wizard.addPage(page)
        page.wizard() # crash here if the bug still exists due to a circular dependency
        wizard.show()

if __name__ == "__main__":
    unittest.main()


#!/usr/bin/env python

'''Using self.connect(signal, method)'''

import unittest

from PySide.QtCore import QObject, SIGNAL, SLOT
from PySide.QtGui import QPushButton, QWidget

from helper import UsesQApplication


class SelfConnect(UsesQApplication):

    def testButtonClickClose(self):
        button = QPushButton()
        button.connect(button, SIGNAL('clicked()'), SLOT('close()'))

        button.show()
        self.assert_(button.isVisible())
        button.click()
        self.assert_(not button.isVisible())

    def testWindowButtonClickClose(self):
        button = QPushButton()
        window = QWidget()
        window.connect(button, SIGNAL('clicked()'), SLOT('close()'))

        window.show()
        self.assert_(window.isVisible())
        button.click()
        self.assert_(not window.isVisible())



if __name__ == '__main__':
    unittest.main()




'''Test cases for QBrush'''

import unittest

from PySide.QtCore import Qt
from PySide.QtGui import QApplication, QColor, QBrush

from helper import UsesQApplication

class Constructor(UsesQApplication):
    '''Test case for constructor of QBrush'''

    def testQColor(self):
        #QBrush(QColor) constructor
        color = QColor('black')
        obj = QBrush(color)
        self.assertEqual(obj.color(), color)

        obj = QBrush(Qt.blue)
        self.assertEqual(obj.color(), Qt.blue)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import *
from PySide.QtGui import *

class MySpinBox(QSpinBox):

    def validate(self,text,pos):
        return QSpinBox.validate(self,text,pos)

class TestBug879 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])
        self.box = MySpinBox()
        self.box.show()

        QTimer.singleShot(0, self.sendKbdEvent)
        QTimer.singleShot(100, app.quit)
        app.exec_()

        self.assertEqual(self.box.text(), '0')

    def sendKbdEvent(self):
        ev = QKeyEvent(QEvent.KeyPress, Qt.Key_A, Qt.NoModifier, 'a')
        QCoreApplication.sendEvent(self.box, ev)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Test suite for QtCore.QUrl'''

import unittest

from PySide.QtCore import QUrl

class QUrlBasicConstructor(unittest.TestCase):
    '''Tests the basic constructors'''

    def testBasic(self):
        #Default constructor for QUrl
        url = QUrl()
        self.assertEqual(url.toString(), "")

    def testSetAttributes(self):
        #Construct QUrl by set* methods
        url = QUrl()

        url.setScheme('ftp')
        self.assertEqual(url.toString(), 'ftp:')

        url.setHost('www.google.com')
        self.assertEqual(url.toString(), 'ftp://www.google.com')

        url.setPort(8080)
        self.assertEqual(url.toString(), 'ftp://www.google.com:8080')

        url.setPath('mail/view')
        self.assertEqual(url.toString(),
                        'ftp://www.google.com:8080/mail/view')

        url.setUserName('john')
        self.assertEqual(url.toString(),
                        'ftp://john@www.google.com:8080/mail/view')

        url.setPassword('abc123')
        self.assertEqual(url.toString(),
                        'ftp://john:abc123@www.google.com:8080/mail/view')

class QueryItemsTest(unittest.TestCase):
    '''Test query item management'''

    def testQueryItems(self):
        #QUrl.queryItems
        url = QUrl('http://www.google.com/search?q=python&hl=en')
        valid_data = [(('q'), ('python')), (('hl'), ('en'))]

        self.assertEqual(sorted(url.queryItems()), sorted(valid_data))

    def testEncodedQueryItems(self):
        #QUrl.encodedQueryItems
        url = QUrl('http://www.google.com/search?q=python&hl=en')
        valid_data = [(('q'), ('python')), (('hl'), ('en'))]

        self.assertEqual(sorted(url.encodedQueryItems()), sorted(valid_data))

    def testSetQueryItems(self):
        #QUrl.setQueryItems
        urla = QUrl('http://www.google.com/search?q=python&hl=en')
        urlb = QUrl('http://www.google.com/search')

        urlb.setQueryItems(urla.queryItems())

        self.assertEqual(urla, urlb)

    def testAddQueryItem(self):
        #QUrl.addQueryItem
        url = QUrl()
        valid_data = [('hl', 'en'), ('user', 'konqui')]

        url.addQueryItem(*valid_data[0])
        self.assertEqual(url.queryItems()[0], valid_data[0])

        url.addQueryItem(*valid_data[1])
        self.assertEqual(sorted(url.queryItems()), sorted(valid_data))

    def testAllEncodedQueryItemsValues(self):
        #QUrl.allEncodedQueryItemValues
        url = QUrl()
        key = 'key'
        valid_data = ['data', 'valid', 'test']

        for i, data in enumerate(valid_data):
            url.addQueryItem(key, data)
            self.assertEqual(url.allEncodedQueryItemValues(key),
                             list(valid_data[:i+1]))


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from PySide.QtCore import QDate, QDateTime, QTime, QUrl
from PySide.QtCore import QLine, QPoint, QRect, QSize

class HashTest(unittest.TestCase):
    def testInsert(self):
        myHash = {}
        qdate = QDate.currentDate()
        qdatetime = QDateTime.currentDateTime()
        qtime = QTime.currentTime()
        qurl = QUrl("http://www.pyside.org")
        qpoint = QPoint(12, 42)

        myHash[qdate] = "QDate"
        myHash[qdatetime] = "QDateTime"
        myHash[qtime] = "QTime"
        myHash[qurl] = "QUrl"
        myHash[qpoint] = "QPoint"

        self.assertEqual(myHash[qdate], "QDate")
        self.assertEqual(myHash[qdatetime], "QDateTime")
        self.assertEqual(myHash[qtime], "QTime")
        self.assertEqual(myHash[qurl], "QUrl")
        self.assertEqual(myHash[qpoint], "QPoint")

    def testQPointHash(self):
        p1 = QPoint(12, 34)
        p2 = QPoint(12, 34)
        self.assertFalse(p1 is p2)
        self.assertEqual(p1, p2)
        self.assertEqual(hash(p1), hash(p2))

    def testQSizeHash(self):
        s1 = QSize(12, 34)
        s2 = QSize(12, 34)
        self.assertFalse(s1 is s2)
        self.assertEqual(s1, s2)
        self.assertEqual(hash(s1), hash(s2))

    def testQRectHash(self):
        r1 = QRect(12, 34, 56, 78)
        r2 = QRect(12, 34, 56, 78)
        self.assertFalse(r1 is r2)
        self.assertEqual(r1, r2)
        self.assertEqual(hash(r1), hash(r2))

    def testQLineHash(self):
        l1 = QLine(12, 34, 56, 78)
        l2 = QLine(12, 34, 56, 78)
        self.assertFalse(l1 is l2)
        self.assertEqual(l1, l2)
        self.assertEqual(hash(l1), hash(l2))

if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-

''' Test case for QObject.receivers()'''

import unittest
from PySide.QtCore import *

def cute_slot():
    pass

class TestQObjectReceivers(unittest.TestCase):
    '''Test case for QObject::receivers'''

    def testBasic(self):
        sender = QObject()
        receiver1 = QObject()
        receiver2 = QObject()
        self.assertEqual(sender.receivers(SIGNAL("")), 0)
        sender.connect(sender, SIGNAL("destroyed()"), receiver1, SLOT("deleteLater()"))
        self.assertEqual(sender.receivers(SIGNAL("destroyed()")), 1)
        sender.connect(sender, SIGNAL("destroyed()"), receiver2, SLOT("deleteLater()"))
        self.assertEqual(sender.receivers(SIGNAL("destroyed()")), 2)
        sender.disconnect(sender, SIGNAL("destroyed()"), receiver2, SLOT("deleteLater()"))
        self.assertEqual(sender.receivers(SIGNAL("destroyed()")), 1)
        del receiver2
        del receiver1
        del sender

    def testPySlots(self):
        sender = QObject()
        receiver = QObject()
        sender.connect(sender, SIGNAL("destroyed()"), cute_slot)
        self.assertEqual(sender.receivers(SIGNAL("destroyed( )")), 1)
        sender.connect(sender, SIGNAL("destroyed()"), receiver, SLOT("deleteLater()"))
        self.assertEqual(sender.receivers(SIGNAL("destroyed()")), 2)
        del sender
        del receiver

    def testPySignals(self):
        sender = QObject()
        receiver = QObject()
        sender.connect(sender, SIGNAL("some_dynamic_signal()"), cute_slot)
        self.assertEqual(sender.receivers(SIGNAL("some_dynamic_signal(  )")), 1)
        sender.connect(sender, SIGNAL("some_dynamic_signal()"), receiver, SLOT("deleteLater()"))
        self.assertEqual(sender.receivers(SIGNAL("some_dynamic_signal(  )")), 2)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import QSizeF
from PySide.QtGui import QGraphicsProxyWidget, QSizePolicy, QPushButton, QGraphicsScene, QGraphicsView

from helper import TimedQApplication

def createItem(minimum, preferred, maximum, name):
    w = QGraphicsProxyWidget()

    w.setWidget(QPushButton(name))
    w.setMinimumSize(minimum)
    w.setPreferredSize(preferred)
    w.setMaximumSize(maximum)
    w.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)

    return w

class TestBug972 (TimedQApplication):

    # Test if the function QGraphicsProxyWidget.setWidget have the correct behavior
    def testIt(self):
        scene = QGraphicsScene()

        minSize = QSizeF(30, 100)
        prefSize = QSizeF(210, 100)
        maxSize = QSizeF(300, 100)

        a = createItem(minSize, prefSize, maxSize, "A")
        b = createItem(minSize, prefSize, maxSize, "B")
        c = createItem(minSize, prefSize, maxSize, "C")
        d = createItem(minSize, prefSize, maxSize, "D")

        view = QGraphicsView(scene)
        view.show()
        self.app.exec_()


if __name__ == "__main__":
    unittest.main()



import unittest
from PySide.QtGui import QFormLayout, QWidget

from helper import UsesQApplication

class QFormLayoutTest(UsesQApplication):

    def testGetItemPosition(self):
        formlayout = QFormLayout()
        row, role = formlayout.getItemPosition(0)
        self.assert_(isinstance(row, int))
        self.assert_(isinstance(role, QFormLayout.ItemRole))
        self.assertEqual(row, -1)

        widget = QWidget()
        formlayout.addRow(widget)
        row, role = formlayout.getItemPosition(0)
        self.assert_(isinstance(row, int))
        self.assert_(isinstance(role, QFormLayout.ItemRole))
        self.assertEqual(row, 0)
        self.assertEqual(role, QFormLayout.SpanningRole)

    def testGetWidgetPosition(self):
        formlayout = QFormLayout()
        widget = QWidget()
        row, role = formlayout.getWidgetPosition(widget)
        self.assert_(isinstance(row, int))
        self.assert_(isinstance(role, QFormLayout.ItemRole))
        self.assertEqual(row, -1)

        formlayout.addRow(widget)
        row, role = formlayout.getWidgetPosition(widget)
        self.assert_(isinstance(row, int))
        self.assert_(isinstance(role, QFormLayout.ItemRole))
        self.assertEqual(row, 0)
        self.assertEqual(role, QFormLayout.SpanningRole)

    def testGetLayoutPosition(self):
        formlayout = QFormLayout()
        layout = QFormLayout()
        row, role = formlayout.getLayoutPosition(layout)
        self.assert_(isinstance(row, int))
        self.assert_(isinstance(role, QFormLayout.ItemRole))
        self.assertEqual(row, -1)

        formlayout.addRow(layout)
        row, role = formlayout.getLayoutPosition(layout)
        self.assert_(isinstance(row, int))
        self.assert_(isinstance(role, QFormLayout.ItemRole))
        self.assertEqual(row, 0)
        self.assertEqual(role, QFormLayout.SpanningRole)


if __name__ == "__main__":
   unittest.main()




#!/usr/bin/python
import unittest
from PySide.QtXml import QXmlSimpleReader

class QXmlSimpleReaderTest(unittest.TestCase):

    def testQXmlSimpleReaderInstatiation(self):
        '''QXmlSimpleReader must be a concrete class not an abstract one.'''
        reader = QXmlSimpleReader()

    def testQXmlSimpleReaderFeatures(self):
        '''Calls the QXmlSimpleReader.features method. The features checked
        (at least the first two) can be found in the QXmlSimpleReader documentation:
        http://qt.nokia.com/doc/4.6/qxmlsimplereader.html#setFeature
        '''
        reader = QXmlSimpleReader()
        hasFeature, ok = reader.feature('http://xml.org/sax/features/namespaces')
        self.assertEqual((hasFeature, ok), (True, True))

        hasFeature, ok = reader.feature('http://xml.org/sax/features/namespace-prefixes')
        self.assertEqual((hasFeature, ok), (False, True))

        hasFeature, ok = reader.feature('foobar')
        self.assertEqual((hasFeature, ok), (False, False))

    def testQXmlSimpleReaderProperty(self):
        '''Tries to get a non existent property.'''
        reader = QXmlSimpleReader()
        prop, ok = reader.property('foo')
        self.assertEqual((prop, ok), (None, False))
        reader.setProperty('foo', 'Something')

if __name__ == '__main__':
    unittest.main()




import unittest

from helper import UsesQApplication

from PySide.QtGui import QTreeWidget, QTreeWidgetItem, QTreeWidgetItemIterator

class QTreeWidgetItemIteratorTest(UsesQApplication):
    def testWidgetIterator(self):
        treeWidget = QTreeWidget()
        treeWidget.setColumnCount(1)
        items = []
        for i in range(10):
            items.append(QTreeWidgetItem(None, ['item: %d' % i]))
        treeWidget.insertTopLevelItems(0, items)

        index = 0
        for it in QTreeWidgetItemIterator(treeWidget):
            self.assertEqual(it.value().text(0), 'item: %d' % index)
            index += 1

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtGui import QApplication
from PySide.QtGui import QMenu

class M2(QMenu):
    def __init__(self,parent=None):
        super(M2,self).__init__(parent)
        self.setTitle(self.tr("M2"))

class TestMenuDerivedClass(unittest.TestCase):
    def aboutToShowHandler(self):
        pass

    def testConnectSignal(self):
        app = QApplication([])
        m2 = M2()
        # Test if the aboutToShow signal was translated to correct type
        m2.aboutToShow.connect(self.aboutToShowHandler)

if __name__ == '__main__':
    unittest.main()



import unittest
from helper import UsesQApplication
from PySide.QtGui import QPixmapCache, QPixmap


class QPixmapCacheTest(UsesQApplication):

    def testWithString(self):
        pm1 = QPixmap()
        ok = QPixmapCache.find('img', pm1)
        self.assertFalse(ok)

        self.assertEqual(QPixmapCache.find('img'), None)

        pm2 = QPixmap()
        ok = QPixmapCache.insert('img', pm2)
        self.assertTrue(ok)

        pm3 = QPixmap()
        ok = QPixmapCache.find('img', pm3)
        self.assertTrue(ok)
        b1 = QPixmapCache.find('img').toImage().bits()
        b2 = pm3.toImage().bits()
        self.assertEqual(QPixmapCache.find('img').toImage().bits(), pm3.toImage().bits())

    def testWithKey(self):
        pm1 = QPixmap()
        ok = QPixmapCache.find(QPixmapCache.Key(), pm1)
        self.assertFalse(ok)

        self.assertEqual(QPixmapCache.find(QPixmapCache.Key()), None)

        pm2 = QPixmap()
        key = QPixmapCache.insert(pm2)

        pm3 = QPixmap()
        ok = QPixmapCache.find(key, pm3)
        self.assertTrue(ok)

        self.assertEqual(QPixmapCache.find(key).toImage().bits(), pm3.toImage().bits())

if __name__ == '__main__':
    unittest.main()




from PySide.QtCore import QTimer, QObject
import sys
import unittest

class TestDestroySignal(unittest.TestCase):
    def onObjectDestroyed(self, timer):
        self.assert_(isinstance(timer, QObject))
        self._destroyed = True

    def testSignal(self):
        self._destroyed = False
        t = QTimer()
        t.destroyed[QObject].connect(self.onObjectDestroyed)
        del t
        self.assert_(self._destroyed)

    def testWithParent(self):
        self._destroyed = False
        p = QTimer()
        t = QTimer(p)
        t.destroyed[QObject].connect(self.onObjectDestroyed)
        del p
        self.assert_(self._destroyed)

if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-

import unittest
from testbinding import TestObject
from PySide.QtCore import QObject

class ListConnectionTest(unittest.TestCase):

    def childrenChanged(self, children):
        self._child = children[0]

    def testConnection(self):
        o = TestObject(0)
        c = QObject()
        c.setObjectName("child")
        self._child = None
        o.childrenChanged.connect(self.childrenChanged)
        o.addChild(c)
        self.assertEquals(self._child.objectName(), "child")

if __name__ == '__main__':
    unittest.main()





import unittest

from PySide.QtGui import QPixmap, QStyle

from helper import UsesQApplication

class StandardPixmapTest(UsesQApplication):
    def testDefaultOptions(self): # Bug 253
        pixmap = self.app.style().standardPixmap(QStyle.SP_DirClosedIcon)
        self.assert_(isinstance(pixmap, QPixmap))

if __name__ == '__main__':
    unittest.main()





'''Test cases for qInstallMsgHandler'''

import unittest
import sys

from PySide.QtCore import *

param = []

def handler(msgt, msg):
    global param
    param = [msgt, msg.strip()]

def handleruseless(msgt, msg):
    pass

class QInstallMsgHandlerTest(unittest.TestCase):

    def tearDown(self):
        # Ensure that next test will have a clear environment
        qInstallMsgHandler(None)

    def testNone(self):
        ret = qInstallMsgHandler(None)
        self.assertEqual(ret, None)

    def testRet(self):
        ret = qInstallMsgHandler(None)
        self.assertEqual(ret, None)
        refcount = sys.getrefcount(handleruseless)
        retNone = qInstallMsgHandler(handleruseless)
        self.assertEqual(sys.getrefcount(handleruseless), refcount + 1)
        rethandler = qInstallMsgHandler(None)
        self.assertEqual(rethandler, handleruseless)
        del rethandler
        self.assertEqual(sys.getrefcount(handleruseless), refcount)

    def testHandler(self):
        rethandler = qInstallMsgHandler(handler)
        qDebug("Test Debug")
        self.assertEqual(param[0], QtDebugMsg)
        self.assertEqual(param[1], "Test Debug")
        qWarning("Test Warning")
        self.assertEqual(param[0], QtWarningMsg)
        self.assertEqual(param[1], "Test Warning")
        qCritical("Test Critical")
        self.assertEqual(param[0], QtCriticalMsg)
        self.assertEqual(param[1], "Test Critical")

if __name__ == '__main__':
    unittest.main()





import unittest

from PySide import QtCore


class QAbsTest(unittest.TestCase):
    '''Tests for QtCore.qAbs'''

    def testBasic(self):
        def check(x):
            self.assertEqual(QtCore.qAbs(x), abs(x))

        check(0)
        check(-10)
        check(10)
        check(10.5)
        check(-10.5)

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtDeclarative import *

import sys
import gc

def register_qml_types():
    class TestClass(QDeclarativeItem):
        def __init__(self, parent = None):
            QDeclarativeItem.__init__(self, parent)

    qmlRegisterType(TestClass, "UserTypes", 1, 0, "TestClass")

def main():
    app = QApplication([])

    # reg qml types here
    register_qml_types()

    # force gc to run
    gc.collect()

    view = QDeclarativeView()
    url = QUrl(__file__.replace(".py", ".qml"))
    view.setSource(url)

if __name__ == "__main__":
    main()



# trimmed down diagramscene.py to demonstrate crash in sizeHint()

import sys
from PySide import QtCore, QtGui
import unittest

class CustomWidget(QtGui.QGraphicsProxyWidget):
   def itemChange(self, eventType, value):
      QtGui.QGraphicsProxyWidget.itemChange(self, eventType, value)

class Bug589(unittest.TestCase):
   def testCase(self):
      widget = QtGui.QGraphicsProxyWidget()
      custom = CustomWidget()
      custom.setParentItem(widget)

if __name__ == "__main__":
   app = QtGui.QApplication(sys.argv)
   unittest.main()



from PySide.QtGui import *
from PySide.QtDeclarative import *
from helper import adjust_filename, UsesQApplication

app = QApplication([])
view = QDeclarativeView(adjust_filename('bug_995.qml', __file__))
view.show()
view.resize(200, 200)
item = view.itemAt(100, 100)

# it CAN NOT crash here
print(item)





import unittest

from PySide.QtGui import QApplication

class TestSingleton(unittest.TestCase):
    def testBasic(self):
        a = QApplication([])
        self.assertRaises(RuntimeError, QApplication, [])

if __name__ == '__main__':
    unittest.main()



import unittest
import PySide

class TestVersionInfo(unittest.TestCase):
    def testIt(self):

        v = PySide.__version_info__
        self.assertEqual(type(v), tuple)
        self.assertEqual(len(v), 5)
        self.assertEqual(type(v[0]), int)
        self.assertEqual(type(v[1]), int)
        self.assertEqual(type(v[2]), int)
        self.assertEqual(type(v[3]), str)
        self.assertEqual(type(v[4]), int)

        self.assertEqual(type(PySide.__version__), str)


if __name__ == '__main__':
    unittest.main()



import unittest
import os
from helper import UsesQApplication

from PySide import QtCore, QtGui
from PySide.QtUiTools import QUiLoader

class MyQUiLoader(QUiLoader):
    def __init__(self, baseinstance):
        QUiLoader.__init__(self)
        self.baseinstance = baseinstance
        self._widgets = []

    def createWidget(self, className, parent=None, name=""):
        widget = QUiLoader.createWidget(self, className, parent, name)
        self._widgets.append(widget)
        if parent is None:
            return self.baseinstance
        else:
            setattr(self.baseinstance, name, widget)
            return widget

class ButTest(UsesQApplication):
    def testCase(self):
        w = QtGui.QWidget()
        loader = MyQUiLoader(w)

        filePath = os.path.join(os.path.dirname(__file__), 'minimal.ui')
        ui = loader.load(filePath)

        self.assertEqual(len(loader._widgets), 1)
        self.assertEqual(type(loader._widgets[0]), QtGui.QFrame)

if __name__ == '__main__':
    unittest.main()





'''(Very) Simple test case for missing names from QtGui'''

import unittest
from PySide import QtGui

class MissingClasses(unittest.TestCase):
    def testQDrag(self): # Bug 222
        getattr(QtGui, 'QDrag')

    def testQDropEvent(self): # Bug 255
        getattr(QtGui, 'QDropEvent')

class MissingMembers(unittest.TestCase):

    def testQFontMetricsSize(self): # Bug 223
        QtGui.QFontMetrics.size

    def testQLayoutSetSpacing(self): # Bug 231
        QtGui.QLayout.setSpacing

    def testQImageLoad(self): # Bug 257
        QtGui.QImage.load

    def testQStandardItemModelinsertRow(self): # Bug 227
        QtGui.QStandardItemModel.insertRow

if __name__ == '__main__':
    unittest.main()



from PySide.QtGui import QApplication, QLabel, QMacStyle
from PySide.QtCore import QObject

import unittest

from helper import UsesQApplication

class QMacStyleTest(UsesQApplication):
    def testWidgetStyle(self):
        w = QLabel('Hello')
        self.assertTrue(isinstance(w.style(), QMacStyle))

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from sys import getrefcount
from PySide.QtCore import *

def addStates(transition):
    sx = QState()
    sy = QState()
    transition.setTargetStates([sx, sy])

def addAnimation(transition):
    animation = QParallelAnimationGroup()
    transition.addAnimation(animation)

class QAbstractTransitionTest(unittest.TestCase):

    def testBasic(self):
        app = QCoreApplication([])

        o = QObject()
        o.setProperty("text", "INdT")

        machine = QStateMachine()
        s1 = QState()
        s1.assignProperty(o, "text", "Rocks")

        s2 = QFinalState()
        t = s1.addTransition(o, SIGNAL("change()"), s2)

        self.assertEqual(t.targetStates(), [s2])

        addStates(t)
        self.assertEqual(len(t.targetStates()), 2)

        animation = QParallelAnimationGroup()
        t.addAnimation(animation)

        self.assertEqual(t.animations(), [animation])

        addAnimation(t)
        self.assertEqual(t.animations()[0].parent(), None)

        machine.addState(s1)
        machine.addState(s2)
        machine.setInitialState(s1)
        machine.start()

        QTimer.singleShot(100, app.quit)
        app.exec_()

    def testRefCountOfTargetState(self):
        transition = QEventTransition()
        state1 = QState()
        refcount1 = getrefcount(state1)

        transition.setTargetState(state1)

        self.assertEqual(transition.targetState(), state1)
        self.assertEqual(getrefcount(transition.targetState()), refcount1 + 1)

        state2 = QState()
        refcount2 = getrefcount(state2)

        transition.setTargetState(state2)

        self.assertEqual(transition.targetState(), state2)
        self.assertEqual(getrefcount(transition.targetState()), refcount2 + 1)
        self.assertEqual(getrefcount(state1), refcount1)

        del transition

        self.assertEqual(getrefcount(state2), refcount2)

    def testRefCountOfTargetStates(self):
        transition = QEventTransition()
        state1 = QState()
        state2 = QState()
        states = [state1, state2]
        refcount1 = getrefcount(state1)
        refcount2 = getrefcount(state2)

        transition.setTargetStates(states)

        self.assertEqual(transition.targetStates(), states)
        self.assertEqual(transition.targetState(), state1)
        self.assertEqual(getrefcount(transition.targetStates()[0]), refcount1 + 1)
        self.assertEqual(getrefcount(transition.targetStates()[1]), refcount2 + 1)

        del states
        del transition

        self.assertEqual(getrefcount(state1), refcount1 - 1)
        self.assertEqual(getrefcount(state2), refcount2 - 1)

    def testRefCountOfTargetStatesAfterSingleTargetState(self):
        transition = QEventTransition()
        state0 = QState()
        refcount0 = getrefcount(state0)

        transition.setTargetState(state0)

        self.assertEqual(transition.targetState(), state0)
        self.assertEqual(getrefcount(transition.targetState()), refcount0 + 1)

        state1 = QState()
        state2 = QState()
        states = [state1, state2]
        refcount1 = getrefcount(state1)
        refcount2 = getrefcount(state2)

        transition.setTargetStates(states)

        self.assertEqual(getrefcount(state0), refcount0)
        self.assertEqual(transition.targetStates(), states)
        self.assertEqual(transition.targetState(), state1)
        self.assertEqual(getrefcount(transition.targetStates()[0]), refcount1 + 1)
        self.assertEqual(getrefcount(transition.targetStates()[1]), refcount2 + 1)

        del states
        del transition

        self.assertEqual(getrefcount(state1), refcount1 - 1)
        self.assertEqual(getrefcount(state2), refcount2 - 1)

    def testRefCountOfTargetStatesBeforeSingleTargetState(self):
        transition = QEventTransition()
        state1 = QState()
        state2 = QState()
        states = [state1, state2]
        refcount1 = getrefcount(state1)
        refcount2 = getrefcount(state2)

        transition.setTargetStates(states)

        self.assertEqual(transition.targetStates(), states)
        self.assertEqual(transition.targetState(), state1)
        self.assertEqual(getrefcount(transition.targetStates()[0]), refcount1 + 1)
        self.assertEqual(getrefcount(transition.targetStates()[1]), refcount2 + 1)

        state3 = QState()
        refcount3 = getrefcount(state3)

        transition.setTargetState(state3)

        self.assertEqual(transition.targetState(), state3)
        self.assertEqual(getrefcount(transition.targetState()), refcount3 + 1)

        del states

        self.assertEqual(getrefcount(state1), refcount1 - 1)
        self.assertEqual(getrefcount(state2), refcount2 - 1)

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import *

class MyModel (QAbstractListModel):
    def rowCount(self, parent = None):
        return 3

class TestBug706(unittest.TestCase):

    def mySlot(self, idx, start, end):
        self.start = start
        self.end = end

    def testIt(self):
        self.start = None
        self.end = None

        app = QCoreApplication([])
        model = MyModel()
        model.columnsAboutToBeInserted.connect(self.mySlot)
        model.columnsAboutToBeInserted.emit(QModelIndex(), 0, 1)
        self.assertEqual(self.start, 0)
        self.assertEqual(self.end, 1)

if __name__ == '__main__':
    unittest.main()



import unittest

from helper import UsesQApplication

from PySide.QtGui import QDoubleSpinBox, QGraphicsBlurEffect

class TestSignalConnection(UsesQApplication):
    def testFloatSignal(self):
        foo1 = QDoubleSpinBox()
        foo2 = QDoubleSpinBox()
        foo1.valueChanged[float].connect(foo2.setValue)
        foo2.valueChanged[float].connect(foo1.setValue)
        foo1.setValue(0.42)
        self.assertEqual(foo1.value(), foo2.value())

    def testQRealSignal(self):
        foo1 = QDoubleSpinBox()
        effect = QGraphicsBlurEffect()
        effect.blurRadiusChanged['qreal'].connect(foo1.setValue) # check if qreal is a valid type
        effect.setBlurRadius(0.42)
        self.assertAlmostEqual(foo1.value(), effect.blurRadius())

if __name__ == '__main__':
    unittest.main()




'''QtTest mouse click functionalities'''

import unittest

from PySide.QtCore import Qt, QObject
from PySide.QtGui import QPushButton, QLineEdit
from PySide.QtTest import QTest

from helper import UsesQApplication

class MouseClickTest(UsesQApplication):

    def testBasic(self):
        '''QTest.mouseClick with QCheckBox'''
        button = QPushButton()
        button.setCheckable(True)
        button.setChecked(False)

        QTest.mouseClick(button, Qt.LeftButton)
        self.assert_(button.isChecked())

        QTest.mouseClick(button, Qt.LeftButton)
        self.assertFalse(button.isChecked())


if __name__ == '__main__':
    unittest.main()




'''Test case for timeout() signals from QTimer object.'''

import unittest
import os
import sys
from tempfile import mkstemp
from PySide.QtCore import QObject, QTimer, SIGNAL
from helper import UsesQCoreApplication

class WatchDog(QObject):
    '''Exits the QCoreApplication main loop after sometime.'''

    def __init__(self, watched):
        QObject.__init__(self)
        self.times_called = 0
        self.watched = watched

    def timerEvent(self, evt):
        self.times_called += 1
        if self.times_called == 20:
            self.watched.exit_app_cb()


class TestTimeoutSignal(UsesQCoreApplication):
    '''Test case to check if the signals are really being caught'''

    def setUp(self):
        #Acquire resources
        UsesQCoreApplication.setUp(self)
        self.watchdog = WatchDog(self)
        self.timer = QTimer()
        self.called = False

    def tearDown(self):
        #Release resources
        del self.watchdog
        del self.timer
        del self.called
        UsesQCoreApplication.tearDown(self)

    def callback(self, *args):
        #Default callback
        self.called = True

    def testTimeoutSignal(self):
        #Test the QTimer timeout() signal
        refCount = sys.getrefcount(self.timer)
        QObject.connect(self.timer, SIGNAL('timeout()'), self.callback)
        self.timer.start(4)
        self.watchdog.startTimer(10)

        self.app.exec_()

        self.assert_(self.called)
        self.assertEqual(sys.getrefcount(self.timer), refCount)

if __name__ == '__main__':
    unittest.main()




from PySide.QtGui import *
from PySide.QtCore import *

app = QApplication([])
QTimer.singleShot(200, app.quit)

# This test for a dead lock in QFileDialog.getOpenFileNames, the test fail with a timeout if the dead lock exists.
QFileDialog.getOpenFileNames(None, "caption", QDir.homePath(), None, "", QFileDialog.DontUseNativeDialog)



#!/usr/bin/python
# -*- coding: utf-8 -*-
import unittest

from PySide.QtDeclarative import QDeclarativeView, QDeclarativeItem
from helper import TimedQApplication

class TestBug915(TimedQApplication):
    def testReturnPolicy(self):
        view = QDeclarativeView()

        item1 = QDeclarativeItem()
        item1.setObjectName("Item1")
        view.scene().addItem(item1)
        self.assertEqual(item1.objectName(), "Item1") # check if the item still valid

        item2 = QDeclarativeItem()
        item2.setObjectName("Item2")
        item1.scene().addItem(item2)
        item1 = None
        self.assertEqual(item2.objectName(), "Item2") # check if the item still valid

        view = None

if __name__ == '__main__':
    unittest.main()





import functools
import unittest

from PySide.QtCore import QObject, Slot, Signal, SIGNAL

def log_exception():
    def log_exception_decorator(func):
        @functools.wraps(func)
        def wrapper(*args, **kwds):
            try:
                return func(*args, **kwds)
            except Exception:
                raise

        return wrapper

    return log_exception_decorator


def log_exception2():
    def log_exception_decorator(func):
        def wrapper(*args, **kwds):
            try:
                return func(*args, **kwds)
            except Exception:
                raise

        return wrapper

    return log_exception_decorator

class MyObject(QObject):

    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self._mySlotcalled = False
        self._mySlot2called = False

    @Slot()
    @log_exception()
    def mySlot(self):
        self._mySlotcalled = True

    @Slot(name="mySlot2")
    @log_exception2()
    def mySlot2(self):
        self._mySlot2called = True

    def poke(self):
        self.events.emit()

    events = Signal()


class SlotWithDecoratorTest(unittest.TestCase):
    def testSlots(self):
        o = MyObject()
        self.assert_(o.metaObject().indexOfSlot("mySlot()") > 0)
        self.assert_(o.metaObject().indexOfSlot("mySlot2()") > 0)

        o.events.connect(o.mySlot)
        o.events.connect(o.mySlot2)
        o.poke()
        self.assertTrue(o._mySlotcalled)
        self.assertTrue(o._mySlot2called)

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtCore import *
from PySide.QtGui import *

class TestBug736 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])
        slider = QSlider(Qt.Horizontal)
        slider2 = QSlider(Qt.Horizontal)

        slider2.setMaximum(10)
        slider.valueChanged[int].connect(slider2.setMaximum)
        slider.valueChanged[int].emit(100)
        self.assertEqual(slider2.maximum(), 100)


if __name__ == '__main__':
    unittest.main()



''' unit test for BUG #1077 '''

from PySide import QtCore, QtGui
import time

class Highlighter(QtGui.QSyntaxHighlighter):
    def __init__(self, parent, mode):
        QtGui.QSyntaxHighlighter.__init__(self, parent)
        self.tstamp = time.time()

if __name__ == "__main__":
    app = QtGui.QApplication([])
    python = QtGui.QTextEdit()
    python.setWindowTitle("python")
    hl = Highlighter(python.document(), "python")
    python.show()
    text = hl.document()



#!/usr/bin/env python

import unittest

from sys import getrefcount
from helper import UsesQApplication
from PySide.QtCore import *
from PySide.QtGui import QTableView

class TestModel(QAbstractTableModel):
    def __init__(self, parent=None):
        QAbstractTableModel.__init__(self, parent)
    def rowCount(self, parent):
        return 0
    def columnCount(self, parent):
        return 0
    def data(self, index, role):
        return None

class KeepReferenceTest(UsesQApplication):

    def testModelWithoutParent(self):
        view = QTableView()
        model = TestModel()
        view.setModel(model)
        samemodel = view.model()
        self.assertEqual(model, samemodel)

    def testModelWithParent(self):
        view = QTableView()
        model = TestModel(None)
        view.setModel(model)
        samemodel = view.model()
        self.assertEqual(model, samemodel)

    def testReferenceCounting(self):
        '''Tests reference count of model object referred by view objects.'''
        model1 = TestModel()
        refcount1 = getrefcount(model1)
        view1 = QTableView()
        view1.setModel(model1)
        self.assertEqual(getrefcount(view1.model()), refcount1 + 1)

        view2 = QTableView()
        view2.setModel(model1)
        self.assertEqual(getrefcount(view2.model()), refcount1 + 2)

        model2 = TestModel()
        view2.setModel(model2)
        self.assertEqual(getrefcount(view1.model()), refcount1 + 1)

    def testReferenceCountingWhenDeletingReferrer(self):
        '''Tests reference count of model object referred by deceased view object.'''
        model = TestModel()
        refcount1 = getrefcount(model)
        view = QTableView()
        view.setModel(model)
        self.assertEqual(getrefcount(view.model()), refcount1 + 1)

        del view
        self.assertEqual(getrefcount(model), refcount1)

    def testReferreedObjectSurvivalAfterContextEnd(self):
        '''Model object assigned to a view object must survive after getting out of context.'''
        def createModelAndSetToView(view):
            model = TestModel()
            model.setObjectName('created model')
            view.setModel(model)
        view = QTableView()
        createModelAndSetToView(view)
        model = view.model()

if __name__ == '__main__':
    unittest.main()




from PySide.QtCore import Qt, QPersistentModelIndex
from PySide.QtGui import QStringListModel

if __name__ == '__main__':
    stringListModel = QStringListModel(['one', 'two'])
    idx = stringListModel.index(1, 0)
    persistentModelIndex = QPersistentModelIndex(idx)
    stringListModel.data(persistentModelIndex, Qt.DisplayRole)




# -*- coding: utf-8 -*-

import unittest

from PySide.QtCore import SIGNAL, SLOT

class SIGNALSLOTTests(unittest.TestCase):
    '''Test the output of SIGNAL and SLOT.'''

    def testSIGNAL(self):
        #SIGNAL function
        a = "foobar"
        self.assertEqual(str(SIGNAL(a)), "2foobar")

    def testSLOT(self):
        #SLOT function
        a = "foobar"
        self.assertEqual(str(SLOT(a)), "1foobar")

if __name__ == '__main__':
    unittest.main()



from __future__ import with_statement

import unittest
from PySide.QtCore import *

class MyWriteThread(QThread):
    def __init__(self, lock):
        QThread.__init__(self)
        self.lock = lock
        self.started = False
        self.canQuit = False

    def run(self):
        self.started = True
        while not self.lock.tryLockForWrite():
            pass
        self.canQuit = True

class MyReadThread(QThread):
    def __init__(self, lock):
        QThread.__init__(self)
        self.lock = lock
        self.started = False
        self.canQuit = False

    def run(self):
        self.started = True
        while not self.lock.tryLockForRead():
            pass
        self.canQuit = True

class MyMutexedThread(QThread):
    def __init__(self, mutex):
        QThread.__init__(self)
        self.mutex = mutex
        self.started = False
        self.canQuit = False

    def run(self):
        self.started = True
        while not self.mutex.tryLock():
            pass
        self.canQuit = True

class TestQMutex (unittest.TestCase):

    def testReadLocker(self):
        lock = QReadWriteLock()
        thread = MyWriteThread(lock)

        with QReadLocker(lock):
            thread.start()
            while not thread.started:
                pass
            self.assertFalse(thread.canQuit)

        thread.wait()
        self.assertTrue(thread.canQuit)

    def testWriteLocker(self):
        lock = QReadWriteLock()
        thread = MyReadThread(lock)

        with QWriteLocker(lock):
            thread.start()
            while not thread.started:
                pass
            self.assertFalse(thread.canQuit)

        thread.wait()
        self.assertTrue(thread.canQuit)

    def testMutexLocker(self):
        mutex = QMutex()
        thread = MyMutexedThread(mutex)

        with QMutexLocker(mutex):
            thread.start()
            while not thread.started:
                pass
            self.assertFalse(thread.canQuit)

        thread.wait()
        self.assertTrue(thread.canQuit)

if __name__ == '__main__':
    unittest.main()




import sys
import unittest
import helper
from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtDeclarative import *

class PieSlice (QDeclarativeItem):

    def __init__(self, parent = None):
        QDeclarativeItem.__init__(self, parent)
        # need to disable this flag to draw inside a QDeclarativeItem
        self.setFlag(QGraphicsItem.ItemHasNoContents, False)
        self._color = QColor()
        self._fromAngle = 0
        self._angleSpan = 0

    def getColor(self):
        return self._color

    def setColor(self, value):
        self._color = value

    def getFromAngle(self):
        return self._angle

    def setFromAngle(self, value):
        self._fromAngle = value

    def getAngleSpan(self):
        return self._angleSpan

    def setAngleSpan(self, value):
        self._angleSpan = value

    color = Property(QColor, getColor, setColor)
    fromAngle = Property(int, getFromAngle, setFromAngle)
    angleSpan = Property(int, getAngleSpan, setAngleSpan)

    def paint(self, painter, options, widget):
        global paintCalled
        pen = QPen(self._color, 2)
        painter.setPen(pen);
        painter.setRenderHints(QPainter.Antialiasing, True);
        painter.drawPie(self.boundingRect(), self._fromAngle * 16, self._angleSpan * 16);
        paintCalled = True

class PieChart (QDeclarativeItem):

    def __init__(self, parent = None):
        QDeclarativeItem.__init__(self, parent)
        self._name = ''
        self._slices = []

    def getName(self):
        return self._name

    def setName(self, value):
        self._name = value

    name = Property(str, getName, setName)

    def appendSlice(self, _slice):
        global appendCalled
        _slice.setParentItem(self)
        self._slices.append(_slice)
        appendCalled = True

    slices = ListProperty(PieSlice, append=appendSlice)

appendCalled = False
paintCalled = False

class TestQmlSupport(unittest.TestCase):

    def testIt(self):
        app = QApplication([])

        qmlRegisterType(PieChart, 'Charts', 1, 0, 'PieChart');
        qmlRegisterType(PieSlice, "Charts", 1, 0, "PieSlice");

        view = QDeclarativeView()
        view.setSource(QUrl.fromLocalFile(helper.adjust_filename('registertype.qml', __file__)))
        view.show()
        QTimer.singleShot(250, view.close)
        app.exec_()
        self.assertTrue(appendCalled)
        self.assertTrue(paintCalled)

if __name__ == '__main__':
    unittest.main()



import unittest

from helper import UsesQApplication

from PySide.QtCore import QTimer
from PySide.QtGui import QPainter, QFont, QFontInfo, QWidget, qApp

class MyWidget(QWidget):
    def paintEvent(self, e):
        p = QPainter(self)
        self._info = p.fontInfo()
        self._app.quit()


class TestQPainter(UsesQApplication):
    def testFontInfo(self):
        w = MyWidget()
        w._app = self.app
        w._info = None
        QTimer.singleShot(300, w.show)
        self.app.exec_()
        self.assert_(w._info)

if __name__ == '__main__':
    unittest.main()



''' unit test for BUG #1091 '''

import unittest
from PySide import QtGui

class QPainterTestCase(unittest.TestCase):
    def testIt(self):
        self.assertTrue("PixmapFragment" in dir(QtGui.QPainter))
        self.assertTrue("drawPixmapFragments" in dir(QtGui.QPainter))

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python

import unittest
from helper import UsesQApplication

from testbinding import TestView
from PySide.QtCore import Qt
from PySide.QtGui import QAbstractItemDelegate, QComboBox

id_text = 'This is me'

class DelegateDoesntKeepReferenceToEditor(QAbstractItemDelegate):
    def createEditor(self, parent, option, index):
        comboBox = QComboBox(parent)
        comboBox.addItem(id_text)
        return comboBox


class DelegateKeepsReferenceToEditor(QAbstractItemDelegate):
    def __init__(self, parent=None):
        QAbstractItemDelegate.__init__(self, parent)
        self.comboBox = QComboBox()
        self.comboBox.addItem(id_text)

    def createEditor(self, parent, option, index):
        self.comboBox.setParent(parent)
        return self.comboBox


class EditorCreatedByDelegateTest(UsesQApplication):

    def testDelegateDoesntKeepReferenceToEditor(self):
        view = TestView(None)
        delegate = DelegateDoesntKeepReferenceToEditor()
        view.setItemDelegate(delegate)
        editor = view.getEditorWidgetFromItemDelegate()
        self.assertEqual(type(editor), QComboBox)
        self.assertEqual(editor.count(), 1)
        self.assertEqual(editor.itemData(0, Qt.DisplayRole), id_text)
        editor.metaObject()

    def testDelegateKeepsReferenceToEditor(self):
        view = TestView(None)
        delegate = DelegateKeepsReferenceToEditor()
        view.setItemDelegate(delegate)
        editor = view.getEditorWidgetFromItemDelegate()
        self.assertEqual(type(editor), QComboBox)
        self.assertEqual(editor.count(), 1)
        self.assertEqual(editor.itemData(0, Qt.DisplayRole), id_text)
        editor.metaObject()


if __name__ == '__main__':
    unittest.main()





import unittest

from PySide.QtCore import QAbstractTableModel
from PySide.QtGui import QTableWidget
from helper import UsesQApplication

class QPenTest(UsesQApplication):

    def testItemModel(self):
        tv = QTableWidget()

        self.assertEqual(type(tv.model()), QAbstractTableModel)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
# -*- coding: utf-8 -*-
# Testcase for PySide bug 847
# Released under the same terms as PySide itself
# 2011-05-04 Thomas Perl <m@thp.io>

import unittest

from PySide.QtCore import Slot, Signal, QUrl
from PySide.QtDeclarative import QDeclarativeView

from helper import adjust_filename, UsesQApplication

class View(QDeclarativeView):
    def __init__(self):
        QDeclarativeView.__init__(self)
        self.setSource(QUrl.fromLocalFile(adjust_filename('bug_847.qml', __file__)))
        self.rootObject().setProperty('pythonObject', self)

    @Slot(int, int)
    def blubb(self, x, y):
        self.called.emit(x, y)

    called = Signal(int, int)


class TestQML(UsesQApplication):
    def done(self, x, y):
        self._sucess = True
        self.app.quit()

    def testPythonSlot(self):
        self._sucess = False
        view = View()
        view.called.connect(self.done)
        view.show()
        self.app.exec_()
        self.assertTrue(self._sucess)

if __name__ == '__main__':
    unittest.main()

